# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/vesting/module/v1/module.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.cosmos.app.v1alpha1 import module_pb2 as cosmos_dot_app_dot_v1alpha1_dot_module__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%cosmos/vesting/module/v1/module.proto\x12\x18\x63osmos.vesting.module.v1\x1a cosmos/app/v1alpha1/module.proto\"=\n\x06Module:3\xba\xc0\x96\xda\x01-\n+github.com/cosmos/cosmos-sdk/x/auth/vestingB\xae\x01\n\x1c\x63om.cosmos.vesting.module.v1B\x0bModuleProtoP\x01\xa2\x02\x03\x43VM\xaa\x02\x18\x43osmos.Vesting.Module.V1\xca\x02\x18\x43osmos\\Vesting\\Module\\V1\xe2\x02$Cosmos\\Vesting\\Module\\V1\\GPBMetadata\xea\x02\x1b\x43osmos::Vesting::Module::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.vesting.module.v1.module_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\034com.cosmos.vesting.module.v1B\013ModuleProtoP\001\242\002\003CVM\252\002\030Cosmos.Vesting.Module.V1\312\002\030Cosmos\\Vesting\\Module\\V1\342\002$Cosmos\\Vesting\\Module\\V1\\GPBMetadata\352\002\033Cosmos::Vesting::Module::V1'
  _globals['_MODULE']._loaded_options = None
  _globals['_MODULE']._serialized_options = b'\272\300\226\332\001-\n+github.com/cosmos/cosmos-sdk/x/auth/vesting'
  _globals['_MODULE']._serialized_start=101
  _globals['_MODULE']._serialized_end=162
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/base/tendermint/v1beta1/query.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from pyinjective.proto.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from pyinjective.proto.cometbft.p2p.v1 import types_pb2 as cometbft_dot_p2p_dot_v1_dot_types__pb2
from pyinjective.proto.cometbft.types.v1 import types_pb2 as cometbft_dot_types_dot_v1_dot_types__pb2
from pyinjective.proto.cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from pyinjective.proto.cosmos.base.tendermint.v1beta1 import types_pb2 as cosmos_dot_base_dot_tendermint_dot_v1beta1_dot_types__pb2
from pyinjective.proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from pyinjective.proto.cometbft.types.v1 import block_pb2 as cometbft_dot_types_dot_v1_dot_block__pb2
from pyinjective.proto.amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*cosmos/base/tendermint/v1beta1/query.proto\x12\x1e\x63osmos.base.tendermint.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x19google/protobuf/any.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1b\x63ometbft/p2p/v1/types.proto\x1a\x1d\x63ometbft/types/v1/types.proto\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a*cosmos/base/tendermint/v1beta1/types.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x1d\x63ometbft/types/v1/block.proto\x1a\x11\x61mino/amino.proto\"\x80\x01\n\x1eGetValidatorSetByHeightRequest\x12\x16\n\x06height\x18\x01 \x01(\x03R\x06height\x12\x46\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequestR\npagination\"\xd8\x01\n\x1fGetValidatorSetByHeightResponse\x12!\n\x0c\x62lock_height\x18\x01 \x01(\x03R\x0b\x62lockHeight\x12I\n\nvalidators\x18\x02 \x03(\x0b\x32).cosmos.base.tendermint.v1beta1.ValidatorR\nvalidators\x12G\n\npagination\x18\x03 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponseR\npagination\"f\n\x1cGetLatestValidatorSetRequest\x12\x46\n\npagination\x18\x01 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequestR\npagination\"\xd6\x01\n\x1dGetLatestValidatorSetResponse\x12!\n\x0c\x62lock_height\x18\x01 \x01(\x03R\x0b\x62lockHeight\x12I\n\nvalidators\x18\x02 \x03(\x0b\x32).cosmos.base.tendermint.v1beta1.ValidatorR\nvalidators\x12G\n\npagination\x18\x03 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponseR\npagination\"\xbe\x01\n\tValidator\x12\x32\n\x07\x61\x64\x64ress\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x07\x61\x64\x64ress\x12-\n\x07pub_key\x18\x02 \x01(\x0b\x32\x14.google.protobuf.AnyR\x06pubKey\x12!\n\x0cvoting_power\x18\x03 \x01(\x03R\x0bvotingPower\x12+\n\x11proposer_priority\x18\x04 \x01(\x03R\x10proposerPriority\"1\n\x17GetBlockByHeightRequest\x12\x16\n\x06height\x18\x01 \x01(\x03R\x06height\"\xc5\x01\n\x18GetBlockByHeightResponse\x12\x35\n\x08\x62lock_id\x18\x01 \x01(\x0b\x32\x1a.cometbft.types.v1.BlockIDR\x07\x62lockId\x12.\n\x05\x62lock\x18\x02 \x01(\x0b\x32\x18.cometbft.types.v1.BlockR\x05\x62lock\x12\x42\n\tsdk_block\x18\x03 \x01(\x0b\x32%.cosmos.base.tendermint.v1beta1.BlockR\x08sdkBlock\"\x17\n\x15GetLatestBlockRequest\"\xc3\x01\n\x16GetLatestBlockResponse\x12\x35\n\x08\x62lock_id\x18\x01 \x01(\x0b\x32\x1a.cometbft.types.v1.BlockIDR\x07\x62lockId\x12.\n\x05\x62lock\x18\x02 \x01(\x0b\x32\x18.cometbft.types.v1.BlockR\x05\x62lock\x12\x42\n\tsdk_block\x18\x03 \x01(\x0b\x32%.cosmos.base.tendermint.v1beta1.BlockR\x08sdkBlock\"\x13\n\x11GetSyncingRequest\".\n\x12GetSyncingResponse\x12\x18\n\x07syncing\x18\x01 \x01(\x08R\x07syncing\"\x14\n\x12GetNodeInfoRequest\"\xc1\x01\n\x13GetNodeInfoResponse\x12L\n\x11\x64\x65\x66\x61ult_node_info\x18\x01 \x01(\x0b\x32 .cometbft.p2p.v1.DefaultNodeInfoR\x0f\x64\x65\x66\x61ultNodeInfo\x12\\\n\x13\x61pplication_version\x18\x02 \x01(\x0b\x32+.cosmos.base.tendermint.v1beta1.VersionInfoR\x12\x61pplicationVersion\"\xa8\x02\n\x0bVersionInfo\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x19\n\x08\x61pp_name\x18\x02 \x01(\tR\x07\x61ppName\x12\x18\n\x07version\x18\x03 \x01(\tR\x07version\x12\x1d\n\ngit_commit\x18\x04 \x01(\tR\tgitCommit\x12\x1d\n\nbuild_tags\x18\x05 \x01(\tR\tbuildTags\x12\x1d\n\ngo_version\x18\x06 \x01(\tR\tgoVersion\x12\x45\n\nbuild_deps\x18\x07 \x03(\x0b\x32&.cosmos.base.tendermint.v1beta1.ModuleR\tbuildDeps\x12,\n\x12\x63osmos_sdk_version\x18\x08 \x01(\tR\x10\x63osmosSdkVersion\"H\n\x06Module\x12\x12\n\x04path\x18\x01 \x01(\tR\x04path\x12\x18\n\x07version\x18\x02 \x01(\tR\x07version\x12\x10\n\x03sum\x18\x03 \x01(\tR\x03sum\"h\n\x10\x41\x42\x43IQueryRequest\x12\x12\n\x04\x64\x61ta\x18\x01 \x01(\x0cR\x04\x64\x61ta\x12\x12\n\x04path\x18\x02 \x01(\tR\x04path\x12\x16\n\x06height\x18\x03 \x01(\x03R\x06height\x12\x14\n\x05prove\x18\x04 \x01(\x08R\x05prove\"\x8e\x02\n\x11\x41\x42\x43IQueryResponse\x12\x12\n\x04\x63ode\x18\x01 \x01(\rR\x04\x63ode\x12\x10\n\x03log\x18\x03 \x01(\tR\x03log\x12\x12\n\x04info\x18\x04 \x01(\tR\x04info\x12\x14\n\x05index\x18\x05 \x01(\x03R\x05index\x12\x10\n\x03key\x18\x06 \x01(\x0cR\x03key\x12\x14\n\x05value\x18\x07 \x01(\x0cR\x05value\x12\x45\n\tproof_ops\x18\x08 \x01(\x0b\x32(.cosmos.base.tendermint.v1beta1.ProofOpsR\x08proofOps\x12\x16\n\x06height\x18\t \x01(\x03R\x06height\x12\x1c\n\tcodespace\x18\n \x01(\tR\tcodespaceJ\x04\x08\x02\x10\x03\"C\n\x07ProofOp\x12\x12\n\x04type\x18\x01 \x01(\tR\x04type\x12\x10\n\x03key\x18\x02 \x01(\x0cR\x03key\x12\x12\n\x04\x64\x61ta\x18\x03 \x01(\x0cR\x04\x64\x61ta\"P\n\x08ProofOps\x12\x44\n\x03ops\x18\x01 \x03(\x0b\x32\'.cosmos.base.tendermint.v1beta1.ProofOpB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\x03ops2\xaf\n\n\x07Service\x12\xa9\x01\n\x0bGetNodeInfo\x12\x32.cosmos.base.tendermint.v1beta1.GetNodeInfoRequest\x1a\x33.cosmos.base.tendermint.v1beta1.GetNodeInfoResponse\"1\x82\xd3\xe4\x93\x02+\x12)/cosmos/base/tendermint/v1beta1/node_info\x12\xa4\x01\n\nGetSyncing\x12\x31.cosmos.base.tendermint.v1beta1.GetSyncingRequest\x1a\x32.cosmos.base.tendermint.v1beta1.GetSyncingResponse\"/\x82\xd3\xe4\x93\x02)\x12\'/cosmos/base/tendermint/v1beta1/syncing\x12\xb6\x01\n\x0eGetLatestBlock\x12\x35.cosmos.base.tendermint.v1beta1.GetLatestBlockRequest\x1a\x36.cosmos.base.tendermint.v1beta1.GetLatestBlockResponse\"5\x82\xd3\xe4\x93\x02/\x12-/cosmos/base/tendermint/v1beta1/blocks/latest\x12\xbe\x01\n\x10GetBlockByHeight\x12\x37.cosmos.base.tendermint.v1beta1.GetBlockByHeightRequest\x1a\x38.cosmos.base.tendermint.v1beta1.GetBlockByHeightResponse\"7\x82\xd3\xe4\x93\x02\x31\x12//cosmos/base/tendermint/v1beta1/blocks/{height}\x12\xd2\x01\n\x15GetLatestValidatorSet\x12<.cosmos.base.tendermint.v1beta1.GetLatestValidatorSetRequest\x1a=.cosmos.base.tendermint.v1beta1.GetLatestValidatorSetResponse\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/cosmos/base/tendermint/v1beta1/validatorsets/latest\x12\xda\x01\n\x17GetValidatorSetByHeight\x12>.cosmos.base.tendermint.v1beta1.GetValidatorSetByHeightRequest\x1a?.cosmos.base.tendermint.v1beta1.GetValidatorSetByHeightResponse\">\x82\xd3\xe4\x93\x02\x38\x12\x36/cosmos/base/tendermint/v1beta1/validatorsets/{height}\x12\xa4\x01\n\tABCIQuery\x12\x30.cosmos.base.tendermint.v1beta1.ABCIQueryRequest\x1a\x31.cosmos.base.tendermint.v1beta1.ABCIQueryResponse\"2\x82\xd3\xe4\x93\x02,\x12*/cosmos/base/tendermint/v1beta1/abci_queryB\x80\x02\n\"com.cosmos.base.tendermint.v1beta1B\nQueryProtoP\x01Z3github.com/cosmos/cosmos-sdk/client/grpc/cmtservice\xa2\x02\x03\x43\x42T\xaa\x02\x1e\x43osmos.Base.Tendermint.V1beta1\xca\x02\x1e\x43osmos\\Base\\Tendermint\\V1beta1\xe2\x02*Cosmos\\Base\\Tendermint\\V1beta1\\GPBMetadata\xea\x02!Cosmos::Base::Tendermint::V1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.base.tendermint.v1beta1.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\"com.cosmos.base.tendermint.v1beta1B\nQueryProtoP\001Z3github.com/cosmos/cosmos-sdk/client/grpc/cmtservice\242\002\003CBT\252\002\036Cosmos.Base.Tendermint.V1beta1\312\002\036Cosmos\\Base\\Tendermint\\V1beta1\342\002*Cosmos\\Base\\Tendermint\\V1beta1\\GPBMetadata\352\002!Cosmos::Base::Tendermint::V1beta1'
  _globals['_VALIDATOR'].fields_by_name['address']._loaded_options = None
  _globals['_VALIDATOR'].fields_by_name['address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_PROOFOPS'].fields_by_name['ops']._loaded_options = None
  _globals['_PROOFOPS'].fields_by_name['ops']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_SERVICE'].methods_by_name['GetNodeInfo']._loaded_options = None
  _globals['_SERVICE'].methods_by_name['GetNodeInfo']._serialized_options = b'\202\323\344\223\002+\022)/cosmos/base/tendermint/v1beta1/node_info'
  _globals['_SERVICE'].methods_by_name['GetSyncing']._loaded_options = None
  _globals['_SERVICE'].methods_by_name['GetSyncing']._serialized_options = b'\202\323\344\223\002)\022\'/cosmos/base/tendermint/v1beta1/syncing'
  _globals['_SERVICE'].methods_by_name['GetLatestBlock']._loaded_options = None
  _globals['_SERVICE'].methods_by_name['GetLatestBlock']._serialized_options = b'\202\323\344\223\002/\022-/cosmos/base/tendermint/v1beta1/blocks/latest'
  _globals['_SERVICE'].methods_by_name['GetBlockByHeight']._loaded_options = None
  _globals['_SERVICE'].methods_by_name['GetBlockByHeight']._serialized_options = b'\202\323\344\223\0021\022//cosmos/base/tendermint/v1beta1/blocks/{height}'
  _globals['_SERVICE'].methods_by_name['GetLatestValidatorSet']._loaded_options = None
  _globals['_SERVICE'].methods_by_name['GetLatestValidatorSet']._serialized_options = b'\202\323\344\223\0026\0224/cosmos/base/tendermint/v1beta1/validatorsets/latest'
  _globals['_SERVICE'].methods_by_name['GetValidatorSetByHeight']._loaded_options = None
  _globals['_SERVICE'].methods_by_name['GetValidatorSetByHeight']._serialized_options = b'\202\323\344\223\0028\0226/cosmos/base/tendermint/v1beta1/validatorsets/{height}'
  _globals['_SERVICE'].methods_by_name['ABCIQuery']._loaded_options = None
  _globals['_SERVICE'].methods_by_name['ABCIQuery']._serialized_options = b'\202\323\344\223\002,\022*/cosmos/base/tendermint/v1beta1/abci_query'
  _globals['_GETVALIDATORSETBYHEIGHTREQUEST']._serialized_start=383
  _globals['_GETVALIDATORSETBYHEIGHTREQUEST']._serialized_end=511
  _globals['_GETVALIDATORSETBYHEIGHTRESPONSE']._serialized_start=514
  _globals['_GETVALIDATORSETBYHEIGHTRESPONSE']._serialized_end=730
  _globals['_GETLATESTVALIDATORSETREQUEST']._serialized_start=732
  _globals['_GETLATESTVALIDATORSETREQUEST']._serialized_end=834
  _globals['_GETLATESTVALIDATORSETRESPONSE']._serialized_start=837
  _globals['_GETLATESTVALIDATORSETRESPONSE']._serialized_end=1051
  _globals['_VALIDATOR']._serialized_start=1054
  _globals['_VALIDATOR']._serialized_end=1244
  _globals['_GETBLOCKBYHEIGHTREQUEST']._serialized_start=1246
  _globals['_GETBLOCKBYHEIGHTREQUEST']._serialized_end=1295
  _globals['_GETBLOCKBYHEIGHTRESPONSE']._serialized_start=1298
  _globals['_GETBLOCKBYHEIGHTRESPONSE']._serialized_end=1495
  _globals['_GETLATESTBLOCKREQUEST']._serialized_start=1497
  _globals['_GETLATESTBLOCKREQUEST']._serialized_end=1520
  _globals['_GETLATESTBLOCKRESPONSE']._serialized_start=1523
  _globals['_GETLATESTBLOCKRESPONSE']._serialized_end=1718
  _globals['_GETSYNCINGREQUEST']._serialized_start=1720
  _globals['_GETSYNCINGREQUEST']._serialized_end=1739
  _globals['_GETSYNCINGRESPONSE']._serialized_start=1741
  _globals['_GETSYNCINGRESPONSE']._serialized_end=1787
  _globals['_GETNODEINFOREQUEST']._serialized_start=1789
  _globals['_GETNODEINFOREQUEST']._serialized_end=1809
  _globals['_GETNODEINFORESPONSE']._serialized_start=1812
  _globals['_GETNODEINFORESPONSE']._serialized_end=2005
  _globals['_VERSIONINFO']._serialized_start=2008
  _globals['_VERSIONINFO']._serialized_end=2304
  _globals['_MODULE']._serialized_start=2306
  _globals['_MODULE']._serialized_end=2378
  _globals['_ABCIQUERYREQUEST']._serialized_start=2380
  _globals['_ABCIQUERYREQUEST']._serialized_end=2484
  _globals['_ABCIQUERYRESPONSE']._serialized_start=2487
  _globals['_ABCIQUERYRESPONSE']._serialized_end=2757
  _globals['_PROOFOP']._serialized_start=2759
  _globals['_PROOFOP']._serialized_end=2826
  _globals['_PROOFOPS']._serialized_start=2828
  _globals['_PROOFOPS']._serialized_end=2908
  _globals['_SERVICE']._serialized_start=2911
  _globals['_SERVICE']._serialized_end=4238
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ibc/applications/interchain_accounts/controller/v1/tx.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.ibc.applications.interchain_accounts.v1 import packet_pb2 as ibc_dot_applications_dot_interchain__accounts_dot_v1_dot_packet__pb2
from pyinjective.proto.ibc.applications.interchain_accounts.controller.v1 import controller_pb2 as ibc_dot_applications_dot_interchain__accounts_dot_controller_dot_v1_dot_controller__pb2
from pyinjective.proto.cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from pyinjective.proto.ibc.core.channel.v1 import channel_pb2 as ibc_dot_core_dot_channel_dot_v1_dot_channel__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;ibc/applications/interchain_accounts/controller/v1/tx.proto\x12\x32ibc.applications.interchain_accounts.controller.v1\x1a\x14gogoproto/gogo.proto\x1a\x34ibc/applications/interchain_accounts/v1/packet.proto\x1a\x43ibc/applications/interchain_accounts/controller/v1/controller.proto\x1a\x17\x63osmos/msg/v1/msg.proto\x1a!ibc/core/channel/v1/channel.proto\"\xbb\x01\n\x1cMsgRegisterInterchainAccount\x12\x14\n\x05owner\x18\x01 \x01(\tR\x05owner\x12#\n\rconnection_id\x18\x02 \x01(\tR\x0c\x63onnectionId\x12\x18\n\x07version\x18\x03 \x01(\tR\x07version\x12\x36\n\x08ordering\x18\x04 \x01(\x0e\x32\x1a.ibc.core.channel.v1.OrderR\x08ordering:\x0e\x88\xa0\x1f\x00\x82\xe7\xb0*\x05owner\"d\n$MsgRegisterInterchainAccountResponse\x12\x1d\n\nchannel_id\x18\x01 \x01(\tR\tchannelId\x12\x17\n\x07port_id\x18\x02 \x01(\tR\x06portId:\x04\x88\xa0\x1f\x00\"\xee\x01\n\tMsgSendTx\x12\x14\n\x05owner\x18\x01 \x01(\tR\x05owner\x12#\n\rconnection_id\x18\x02 \x01(\tR\x0c\x63onnectionId\x12k\n\x0bpacket_data\x18\x03 \x01(\x0b\x32\x44.ibc.applications.interchain_accounts.v1.InterchainAccountPacketDataB\x04\xc8\xde\x1f\x00R\npacketData\x12)\n\x10relative_timeout\x18\x04 \x01(\x04R\x0frelativeTimeout:\x0e\x88\xa0\x1f\x00\x82\xe7\xb0*\x05owner\"5\n\x11MsgSendTxResponse\x12\x1a\n\x08sequence\x18\x01 \x01(\x04R\x08sequence:\x04\x88\xa0\x1f\x00\"\x94\x01\n\x0fMsgUpdateParams\x12\x16\n\x06signer\x18\x01 \x01(\tR\x06signer\x12X\n\x06params\x18\x02 \x01(\x0b\x32:.ibc.applications.interchain_accounts.controller.v1.ParamsB\x04\xc8\xde\x1f\x00R\x06params:\x0f\x88\xa0\x1f\x00\x82\xe7\xb0*\x06signer\"\x19\n\x17MsgUpdateParamsResponse2\x8a\x04\n\x03Msg\x12\xc7\x01\n\x19RegisterInterchainAccount\x12P.ibc.applications.interchain_accounts.controller.v1.MsgRegisterInterchainAccount\x1aX.ibc.applications.interchain_accounts.controller.v1.MsgRegisterInterchainAccountResponse\x12\x8e\x01\n\x06SendTx\x12=.ibc.applications.interchain_accounts.controller.v1.MsgSendTx\x1a\x45.ibc.applications.interchain_accounts.controller.v1.MsgSendTxResponse\x12\xa0\x01\n\x0cUpdateParams\x12\x43.ibc.applications.interchain_accounts.controller.v1.MsgUpdateParams\x1aK.ibc.applications.interchain_accounts.controller.v1.MsgUpdateParamsResponse\x1a\x05\x80\xe7\xb0*\x01\x42\xfc\x02\n6com.ibc.applications.interchain_accounts.controller.v1B\x07TxProtoP\x01ZPgithub.com/cosmos/ibc-go/v8/modules/apps/27-interchain-accounts/controller/types\xa2\x02\x04IAIC\xaa\x02\x31Ibc.Applications.InterchainAccounts.Controller.V1\xca\x02\x31Ibc\\Applications\\InterchainAccounts\\Controller\\V1\xe2\x02=Ibc\\Applications\\InterchainAccounts\\Controller\\V1\\GPBMetadata\xea\x02\x35Ibc::Applications::InterchainAccounts::Controller::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.applications.interchain_accounts.controller.v1.tx_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n6com.ibc.applications.interchain_accounts.controller.v1B\007TxProtoP\001ZPgithub.com/cosmos/ibc-go/v8/modules/apps/27-interchain-accounts/controller/types\242\002\004IAIC\252\0021Ibc.Applications.InterchainAccounts.Controller.V1\312\0021Ibc\\Applications\\InterchainAccounts\\Controller\\V1\342\002=Ibc\\Applications\\InterchainAccounts\\Controller\\V1\\GPBMetadata\352\0025Ibc::Applications::InterchainAccounts::Controller::V1'
  _globals['_MSGREGISTERINTERCHAINACCOUNT']._loaded_options = None
  _globals['_MSGREGISTERINTERCHAINACCOUNT']._serialized_options = b'\210\240\037\000\202\347\260*\005owner'
  _globals['_MSGREGISTERINTERCHAINACCOUNTRESPONSE']._loaded_options = None
  _globals['_MSGREGISTERINTERCHAINACCOUNTRESPONSE']._serialized_options = b'\210\240\037\000'
  _globals['_MSGSENDTX'].fields_by_name['packet_data']._loaded_options = None
  _globals['_MSGSENDTX'].fields_by_name['packet_data']._serialized_options = b'\310\336\037\000'
  _globals['_MSGSENDTX']._loaded_options = None
  _globals['_MSGSENDTX']._serialized_options = b'\210\240\037\000\202\347\260*\005owner'
  _globals['_MSGSENDTXRESPONSE']._loaded_options = None
  _globals['_MSGSENDTXRESPONSE']._serialized_options = b'\210\240\037\000'
  _globals['_MSGUPDATEPARAMS'].fields_by_name['params']._loaded_options = None
  _globals['_MSGUPDATEPARAMS'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_MSGUPDATEPARAMS']._loaded_options = None
  _globals['_MSGUPDATEPARAMS']._serialized_options = b'\210\240\037\000\202\347\260*\006signer'
  _globals['_MSG']._loaded_options = None
  _globals['_MSG']._serialized_options = b'\200\347\260*\001'
  _globals['_MSGREGISTERINTERCHAINACCOUNT']._serialized_start=321
  _globals['_MSGREGISTERINTERCHAINACCOUNT']._serialized_end=508
  _globals['_MSGREGISTERINTERCHAINACCOUNTRESPONSE']._serialized_start=510
  _globals['_MSGREGISTERINTERCHAINACCOUNTRESPONSE']._serialized_end=610
  _globals['_MSGSENDTX']._serialized_start=613
  _globals['_MSGSENDTX']._serialized_end=851
  _globals['_MSGSENDTXRESPONSE']._serialized_start=853
  _globals['_MSGSENDTXRESPONSE']._serialized_end=906
  _globals['_MSGUPDATEPARAMS']._serialized_start=909
  _globals['_MSGUPDATEPARAMS']._serialized_end=1057
  _globals['_MSGUPDATEPARAMSRESPONSE']._serialized_start=1059
  _globals['_MSGUPDATEPARAMSRESPONSE']._serialized_end=1084
  _globals['_MSG']._serialized_start=1087
  _globals['_MSG']._serialized_end=1609
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/ocr/v1beta1/genesis.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.injective.ocr.v1beta1 import ocr_pb2 as injective_dot_ocr_dot_v1beta1_dot_ocr__pb2
from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#injective/ocr/v1beta1/genesis.proto\x12\x15injective.ocr.v1beta1\x1a\x1finjective/ocr/v1beta1/ocr.proto\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\"\x94\x06\n\x0cGenesisState\x12;\n\x06params\x18\x01 \x01(\x0b\x32\x1d.injective.ocr.v1beta1.ParamsB\x04\xc8\xde\x1f\x00R\x06params\x12\x44\n\x0c\x66\x65\x65\x64_configs\x18\x02 \x03(\x0b\x32!.injective.ocr.v1beta1.FeedConfigR\x0b\x66\x65\x65\x64\x43onfigs\x12_\n\x17latest_epoch_and_rounds\x18\x03 \x03(\x0b\x32(.injective.ocr.v1beta1.FeedEpochAndRoundR\x14latestEpochAndRounds\x12V\n\x12\x66\x65\x65\x64_transmissions\x18\x04 \x03(\x0b\x32\'.injective.ocr.v1beta1.FeedTransmissionR\x11\x66\x65\x65\x64Transmissions\x12r\n\x1blatest_aggregator_round_ids\x18\x05 \x03(\x0b\x32\x33.injective.ocr.v1beta1.FeedLatestAggregatorRoundIDsR\x18latestAggregatorRoundIds\x12\x44\n\x0creward_pools\x18\x06 \x03(\x0b\x32!.injective.ocr.v1beta1.RewardPoolR\x0brewardPools\x12Y\n\x17\x66\x65\x65\x64_observation_counts\x18\x07 \x03(\x0b\x32!.injective.ocr.v1beta1.FeedCountsR\x15\x66\x65\x65\x64ObservationCounts\x12[\n\x18\x66\x65\x65\x64_transmission_counts\x18\x08 \x03(\x0b\x32!.injective.ocr.v1beta1.FeedCountsR\x16\x66\x65\x65\x64TransmissionCounts\x12V\n\x12pending_payeeships\x18\t \x03(\x0b\x32\'.injective.ocr.v1beta1.PendingPayeeshipR\x11pendingPayeeships\"t\n\x10\x46\x65\x65\x64Transmission\x12\x17\n\x07\x66\x65\x65\x64_id\x18\x01 \x01(\tR\x06\x66\x65\x65\x64Id\x12G\n\x0ctransmission\x18\x02 \x01(\x0b\x32#.injective.ocr.v1beta1.TransmissionR\x0ctransmission\"z\n\x11\x46\x65\x65\x64\x45pochAndRound\x12\x17\n\x07\x66\x65\x65\x64_id\x18\x01 \x01(\tR\x06\x66\x65\x65\x64Id\x12L\n\x0f\x65poch_and_round\x18\x02 \x01(\x0b\x32$.injective.ocr.v1beta1.EpochAndRoundR\repochAndRound\"g\n\x1c\x46\x65\x65\x64LatestAggregatorRoundIDs\x12\x17\n\x07\x66\x65\x65\x64_id\x18\x01 \x01(\tR\x06\x66\x65\x65\x64Id\x12.\n\x13\x61ggregator_round_id\x18\x02 \x01(\x04R\x11\x61ggregatorRoundId\"^\n\nRewardPool\x12\x17\n\x07\x66\x65\x65\x64_id\x18\x01 \x01(\tR\x06\x66\x65\x65\x64Id\x12\x37\n\x06\x61mount\x18\x02 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00R\x06\x61mount\"[\n\nFeedCounts\x12\x17\n\x07\x66\x65\x65\x64_id\x18\x01 \x01(\tR\x06\x66\x65\x65\x64Id\x12\x34\n\x06\x63ounts\x18\x02 \x03(\x0b\x32\x1c.injective.ocr.v1beta1.CountR\x06\x63ounts\"7\n\x05\x43ount\x12\x18\n\x07\x61\x64\x64ress\x18\x01 \x01(\tR\x07\x61\x64\x64ress\x12\x14\n\x05\x63ount\x18\x02 \x01(\x04R\x05\x63ount\"t\n\x10PendingPayeeship\x12\x17\n\x07\x66\x65\x65\x64_id\x18\x01 \x01(\tR\x06\x66\x65\x65\x64Id\x12 \n\x0btransmitter\x18\x02 \x01(\tR\x0btransmitter\x12%\n\x0eproposed_payee\x18\x03 \x01(\tR\rproposedPayeeB\xea\x01\n\x19\x63om.injective.ocr.v1beta1B\x0cGenesisProtoP\x01ZIgithub.com/InjectiveLabs/injective-core/injective-chain/modules/ocr/types\xa2\x02\x03IOX\xaa\x02\x15Injective.Ocr.V1beta1\xca\x02\x15Injective\\Ocr\\V1beta1\xe2\x02!Injective\\Ocr\\V1beta1\\GPBMetadata\xea\x02\x17Injective::Ocr::V1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.ocr.v1beta1.genesis_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\031com.injective.ocr.v1beta1B\014GenesisProtoP\001ZIgithub.com/InjectiveLabs/injective-core/injective-chain/modules/ocr/types\242\002\003IOX\252\002\025Injective.Ocr.V1beta1\312\002\025Injective\\Ocr\\V1beta1\342\002!Injective\\Ocr\\V1beta1\\GPBMetadata\352\002\027Injective::Ocr::V1beta1'
  _globals['_GENESISSTATE'].fields_by_name['params']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_REWARDPOOL'].fields_by_name['amount']._loaded_options = None
  _globals['_REWARDPOOL'].fields_by_name['amount']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE']._serialized_start=150
  _globals['_GENESISSTATE']._serialized_end=938
  _globals['_FEEDTRANSMISSION']._serialized_start=940
  _globals['_FEEDTRANSMISSION']._serialized_end=1056
  _globals['_FEEDEPOCHANDROUND']._serialized_start=1058
  _globals['_FEEDEPOCHANDROUND']._serialized_end=1180
  _globals['_FEEDLATESTAGGREGATORROUNDIDS']._serialized_start=1182
  _globals['_FEEDLATESTAGGREGATORROUNDIDS']._serialized_end=1285
  _globals['_REWARDPOOL']._serialized_start=1287
  _globals['_REWARDPOOL']._serialized_end=1381
  _globals['_FEEDCOUNTS']._serialized_start=1383
  _globals['_FEEDCOUNTS']._serialized_end=1474
  _globals['_COUNT']._serialized_start=1476
  _globals['_COUNT']._serialized_end=1531
  _globals['_PENDINGPAYEESHIP']._serialized_start=1533
  _globals['_PENDINGPAYEESHIP']._serialized_end=1649
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from pyinjective.proto.ibc.lightclients.wasm.v1 import query_pb2 as ibc_dot_lightclients_dot_wasm_dot_v1_dot_query__pb2


class QueryStub(object):
    """Query service for wasm module
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Checksums = channel.unary_unary(
                '/ibc.lightclients.wasm.v1.Query/Checksums',
                request_serializer=ibc_dot_lightclients_dot_wasm_dot_v1_dot_query__pb2.QueryChecksumsRequest.SerializeToString,
                response_deserializer=ibc_dot_lightclients_dot_wasm_dot_v1_dot_query__pb2.QueryChecksumsResponse.FromString,
                _registered_method=True)
        self.Code = channel.unary_unary(
                '/ibc.lightclients.wasm.v1.Query/Code',
                request_serializer=ibc_dot_lightclients_dot_wasm_dot_v1_dot_query__pb2.QueryCodeRequest.SerializeToString,
                response_deserializer=ibc_dot_lightclients_dot_wasm_dot_v1_dot_query__pb2.QueryCodeResponse.FromString,
                _registered_method=True)


class QueryServicer(object):
    """Query service for wasm module
    """

    def Checksums(self, request, context):
        """Get all Wasm checksums
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Code(self, request, context):
        """Get Wasm code for given checksum
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_QueryServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Checksums': grpc.unary_unary_rpc_method_handler(
                    servicer.Checksums,
                    request_deserializer=ibc_dot_lightclients_dot_wasm_dot_v1_dot_query__pb2.QueryChecksumsRequest.FromString,
                    response_serializer=ibc_dot_lightclients_dot_wasm_dot_v1_dot_query__pb2.QueryChecksumsResponse.SerializeToString,
            ),
            'Code': grpc.unary_unary_rpc_method_handler(
                    servicer.Code,
                    request_deserializer=ibc_dot_lightclients_dot_wasm_dot_v1_dot_query__pb2.QueryCodeRequest.FromString,
                    response_serializer=ibc_dot_lightclients_dot_wasm_dot_v1_dot_query__pb2.QueryCodeResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'ibc.lightclients.wasm.v1.Query', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('ibc.lightclients.wasm.v1.Query', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class Query(object):
    """Query service for wasm module
    """

    @staticmethod
    def Checksums(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ibc.lightclients.wasm.v1.Query/Checksums',
            ibc_dot_lightclients_dot_wasm_dot_v1_dot_query__pb2.QueryChecksumsRequest.SerializeToString,
            ibc_dot_lightclients_dot_wasm_dot_v1_dot_query__pb2.QueryChecksumsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Code(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ibc.lightclients.wasm.v1.Query/Code',
            ibc_dot_lightclients_dot_wasm_dot_v1_dot_query__pb2.QueryCodeRequest.SerializeToString,
            ibc_dot_lightclients_dot_wasm_dot_v1_dot_query__pb2.QueryCodeResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/evidence/v1beta1/evidence.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.amino import amino_pb2 as amino_dot_amino__pb2
from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from pyinjective.proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&cosmos/evidence/v1beta1/evidence.proto\x12\x17\x63osmos.evidence.v1beta1\x1a\x11\x61mino/amino.proto\x1a\x14gogoproto/gogo.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x19\x63osmos_proto/cosmos.proto\"\xe8\x01\n\x0c\x45quivocation\x12\x16\n\x06height\x18\x01 \x01(\x03R\x06height\x12=\n\x04time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\r\xc8\xde\x1f\x00\x90\xdf\x1f\x01\xa8\xe7\xb0*\x01R\x04time\x12\x14\n\x05power\x18\x03 \x01(\x03R\x05power\x12\x45\n\x11\x63onsensus_address\x18\x04 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x10\x63onsensusAddress:$\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\x8a\xe7\xb0*\x17\x63osmos-sdk/EquivocationB\xcd\x01\n\x1b\x63om.cosmos.evidence.v1beta1B\rEvidenceProtoP\x01Z\x1d\x63osmossdk.io/x/evidence/types\xa2\x02\x03\x43\x45X\xaa\x02\x17\x43osmos.Evidence.V1beta1\xca\x02\x17\x43osmos\\Evidence\\V1beta1\xe2\x02#Cosmos\\Evidence\\V1beta1\\GPBMetadata\xea\x02\x19\x43osmos::Evidence::V1beta1\xa8\xe2\x1e\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.evidence.v1beta1.evidence_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033com.cosmos.evidence.v1beta1B\rEvidenceProtoP\001Z\035cosmossdk.io/x/evidence/types\242\002\003CEX\252\002\027Cosmos.Evidence.V1beta1\312\002\027Cosmos\\Evidence\\V1beta1\342\002#Cosmos\\Evidence\\V1beta1\\GPBMetadata\352\002\031Cosmos::Evidence::V1beta1\250\342\036\001'
  _globals['_EQUIVOCATION'].fields_by_name['time']._loaded_options = None
  _globals['_EQUIVOCATION'].fields_by_name['time']._serialized_options = b'\310\336\037\000\220\337\037\001\250\347\260*\001'
  _globals['_EQUIVOCATION'].fields_by_name['consensus_address']._loaded_options = None
  _globals['_EQUIVOCATION'].fields_by_name['consensus_address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_EQUIVOCATION']._loaded_options = None
  _globals['_EQUIVOCATION']._serialized_options = b'\210\240\037\000\350\240\037\000\212\347\260*\027cosmos-sdk/Equivocation'
  _globals['_EQUIVOCATION']._serialized_start=169
  _globals['_EQUIVOCATION']._serialized_end=401
# @@protoc_insertion_point(module_scope)



import math
from abc import ABC, abstractmethod
from decimal import Decimal
from typing import Union

from google.protobuf import any_pb2

from pyinjective.core.gas_limit_estimator import GasLimitEstimator
from pyinjective.proto.cosmos.authz.v1beta1 import tx_pb2 as cosmos_authz_tx_pb
from pyinjective.proto.injective.exchange.v2 import (
    order_pb2 as injective_order_v2_pb,
    tx_pb2 as injective_exchange_tx_pb,
)

SPOT_ORDER_CREATION_GAS_LIMIT = 100_000
SPOT_MARKET_ORDER_CREATION_GAS_LIMIT = 50_000
POST_ONLY_SPOT_ORDER_CREATION_GAS_LIMIT = 120_000
DERIVATIVE_ORDER_CREATION_GAS_LIMIT = 120_000
DERIVATIVE_MARKET_ORDER_CREATION_GAS_LIMIT = 105_000
POST_ONLY_DERIVATIVE_ORDER_CREATION_GAS_LIMIT = 140_000
BINARY_OPTIONS_ORDER_CREATION_GAS_LIMIT = DERIVATIVE_ORDER_CREATION_GAS_LIMIT
BINARY_OPTIONS_MARKET_ORDER_CREATION_GAS_LIMIT = DERIVATIVE_MARKET_ORDER_CREATION_GAS_LIMIT
POST_ONLY_BINARY_OPTIONS_ORDER_CREATION_GAS_LIMIT = POST_ONLY_DERIVATIVE_ORDER_CREATION_GAS_LIMIT
SPOT_ORDER_CANCELATION_GAS_LIMIT = 65_000
DERIVATIVE_ORDER_CANCELATION_GAS_LIMIT = 70_000
BINARY_OPTIONS_ORDER_CANCELATION_GAS_LIMIT = DERIVATIVE_ORDER_CANCELATION_GAS_LIMIT

GTB_ORDERS_GAS_MULTIPLIER = "1.1"

DEPOSIT_GAS_LIMIT = 38_000
WITHDRAW_GAS_LIMIT = 35_000
SUBACCOUNT_TRANSFER_GAS_LIMIT = 15_000
EXTERNAL_TRANSFER_GAS_LIMIT = 40_000
INCREASE_POSITION_MARGIN_TRANSFER_GAS_LIMIT = 51_000
DECREASE_POSITION_MARGIN_TRANSFER_GAS_LIMIT = 60_000


class GasHeuristicsGasLimitEstimator(ABC):
    GENERAL_MESSAGE_GAS_LIMIT = 25_000
    BASIC_REFERENCE_GAS_LIMIT = 150_000

    @classmethod
    @abstractmethod
    def applies_to(cls, message: any_pb2.Any) -> bool:
        ...

    @classmethod
    def for_message(cls, message: any_pb2.Any):
        estimator_class = next(
            (
                estimator_subclass
                for estimator_subclass in cls.__subclasses__()
                if estimator_subclass.applies_to(message=message)
            ),
            None,
        )
        if estimator_class is None:
            estimator = GasLimitEstimator.for_message(message=message)
        else:
            estimator = estimator_class(message=message)

        return estimator

    @abstractmethod
    def gas_limit(self) -> int:
        ...

    @staticmethod
    def message_type(message: any_pb2.Any) -> str:
        if isinstance(message, any_pb2.Any):
            message_type = message.type_url
        else:
            message_type = message.DESCRIPTOR.full_name
        return message_type

    @abstractmethod
    def _message_class(self, message: any_pb2.Any):
        ...

    def _parsed_message(self, message: any_pb2.Any) -> any_pb2.Any:
        if isinstance(message, any_pb2.Any):
            parsed_message = self._message_class(message=message).FromString(message.value)
        else:
            parsed_message = message
        return parsed_message

    @staticmethod
    def is_post_only_order(
        order: Union[injective_order_v2_pb.SpotOrder, injective_order_v2_pb.DerivativeOrder],
    ) -> bool:
        return order.order_type in [injective_order_v2_pb.OrderType.BUY_PO, injective_order_v2_pb.OrderType.SELL_PO]


class CreateSpotLimitOrdersGasLimitEstimator(GasHeuristicsGasLimitEstimator):
    def __init__(self, message: any_pb2.Any):
        self._message = self._parsed_message(message=message)

    @classmethod
    def applies_to(cls, message: any_pb2.Any):
        return cls.message_type(message=message).endswith("MsgCreateSpotLimitOrder")

    @staticmethod
    def gas_cost_for_order(order: injective_order_v2_pb.SpotOrder) -> int:
        if GasHeuristicsGasLimitEstimator.is_post_only_order(order):
            gas_cost = POST_ONLY_SPOT_ORDER_CREATION_GAS_LIMIT
        else:
            gas_cost = SPOT_ORDER_CREATION_GAS_LIMIT

        if order.expiration_block > 0:
            gas_cost = math.ceil(Decimal(gas_cost) * Decimal(GTB_ORDERS_GAS_MULTIPLIER))

        return gas_cost

    def gas_limit(self) -> int:
        return self.gas_cost_for_order(self._message.order)

    def _message_class(self, message: any_pb2.Any):
        return injective_exchange_tx_pb.MsgCreateSpotLimitOrder


class CreateSpotMarketOrdersGasLimitEstimator(GasHeuristicsGasLimitEstimator):
    def __init__(self, message: any_pb2.Any):
        self._message = self._parsed_message(message=message)

    @classmethod
    def applies_to(cls, message: any_pb2.Any):
        return cls.message_type(message=message).endswith("MsgCreateSpotMarketOrder")

    def gas_limit(self) -> int:
        return SPOT_MARKET_ORDER_CREATION_GAS_LIMIT

    def _message_class(self, message: any_pb2.Any):
        return injective_exchange_tx_pb.MsgCreateSpotMarketOrder


class CancelSpotOrderGasLimitEstimator(GasHeuristicsGasLimitEstimator):
    def __init__(self, message: any_pb2.Any):
        self._message = self._parsed_message(message=message)

    @classmethod
    def applies_to(cls, message: any_pb2.Any):
        return cls.message_type(message=message).endswith("MsgCancelSpotOrder")

    def gas_limit(self) -> int:
        return SPOT_ORDER_CANCELATION_GAS_LIMIT

    def _message_class(self, message: any_pb2.Any):
        return injective_exchange_tx_pb.MsgCancelSpotOrder


class CreateDerivativeLimitOrdersGasLimitEstimator(GasHeuristicsGasLimitEstimator):
    def __init__(self, message: any_pb2.Any):
        self._message = self._parsed_message(message=message)

    @classmethod
    def applies_to(cls, message: any_pb2.Any):
        return cls.message_type(message=message).endswith("MsgCreateDerivativeLimitOrder")

    @staticmethod
    def gas_cost_for_order(order: injective_order_v2_pb.DerivativeOrder) -> int:
        if GasHeuristicsGasLimitEstimator.is_post_only_order(order=order):
            gas_cost = POST_ONLY_DERIVATIVE_ORDER_CREATION_GAS_LIMIT
        else:
            gas_cost = DERIVATIVE_ORDER_CREATION_GAS_LIMIT

        if order.expiration_block > 0:
            gas_cost = math.ceil(Decimal(gas_cost) * Decimal(GTB_ORDERS_GAS_MULTIPLIER))

        return gas_cost

    def gas_limit(self) -> int:
        return self.gas_cost_for_order(self._message.order)

    def _message_class(self, message: any_pb2.Any):
        return injective_exchange_tx_pb.MsgCreateDerivativeLimitOrder


class CreateDerivativeMarketOrdersGasLimitEstimator(GasHeuristicsGasLimitEstimator):
    def __init__(self, message: any_pb2.Any):
        self._message = self._parsed_message(message=message)

    @classmethod
    def applies_to(cls, message: any_pb2.Any):
        return cls.message_type(message=message).endswith("MsgCreateDerivativeMarketOrder")

    def gas_limit(self) -> int:
        return DERIVATIVE_MARKET_ORDER_CREATION_GAS_LIMIT

    def _message_class(self, message: any_pb2.Any):
        return injective_exchange_tx_pb.MsgCreateDerivativeMarketOrder


class CancelDerivativeOrderGasLimitEstimator(GasHeuristicsGasLimitEstimator):
    def __init__(self, message: any_pb2.Any):
        self._message = self._parsed_message(message=message)

    @classmethod
    def applies_to(cls, message: any_pb2.Any):
        return cls.message_type(message=message).endswith("MsgCancelDerivativeOrder")

    def gas_limit(self) -> int:
        return DERIVATIVE_ORDER_CANCELATION_GAS_LIMIT

    def _message_class(self, message: any_pb2.Any):
        return injective_exchange_tx_pb.MsgCancelDerivativeOrder


class CreateBinaryOptionsLimitOrdersGasLimitEstimator(GasHeuristicsGasLimitEstimator):
    def __init__(self, message: any_pb2.Any):
        self._message = self._parsed_message(message=message)

    @classmethod
    def applies_to(cls, message: any_pb2.Any):
        return cls.message_type(message=message).endswith("MsgCreateBinaryOptionsLimitOrder")

    @staticmethod
    def gas_cost_for_order(order: injective_order_v2_pb.DerivativeOrder) -> int:
        if GasHeuristicsGasLimitEstimator.is_post_only_order(order=order):
            gas_cost = POST_ONLY_BINARY_OPTIONS_ORDER_CREATION_GAS_LIMIT
        else:
            gas_cost = BINARY_OPTIONS_ORDER_CREATION_GAS_LIMIT

        if order.expiration_block > 0:
            gas_cost = math.ceil(Decimal(gas_cost) * Decimal(GTB_ORDERS_GAS_MULTIPLIER))

        return gas_cost

    def gas_limit(self) -> int:
        return self.gas_cost_for_order(self._message.order)

    def _message_class(self, message: any_pb2.Any):
        return injective_exchange_tx_pb.MsgCreateBinaryOptionsLimitOrder


class CreateBinaryOptionsMarketOrdersGasLimitEstimator(GasHeuristicsGasLimitEstimator):
    def __init__(self, message: any_pb2.Any):
        self._message = self._parsed_message(message=message)

    @classmethod
    def applies_to(cls, message: any_pb2.Any):
        return cls.message_type(message=message).endswith("MsgCreateBinaryOptionsMarketOrder")

    def gas_limit(self) -> int:
        return BINARY_OPTIONS_MARKET_ORDER_CREATION_GAS_LIMIT

    def _message_class(self, message: any_pb2.Any):
        return injective_exchange_tx_pb.MsgCreateBinaryOptionsMarketOrder


class CancelBinaryOptionsOrderGasLimitEstimator(GasHeuristicsGasLimitEstimator):
    def __init__(self, message: any_pb2.Any):
        self._message = self._parsed_message(message=message)

    @classmethod
    def applies_to(cls, message: any_pb2.Any):
        return cls.message_type(message=message).endswith("MsgCancelBinaryOptionsOrder")

    def gas_limit(self) -> int:
        return BINARY_OPTIONS_ORDER_CANCELATION_GAS_LIMIT

    def _message_class(self, message: any_pb2.Any):
        return injective_exchange_tx_pb.MsgCancelBinaryOptionsOrder


class BatchCreateSpotLimitOrdersGasLimitEstimator(GasHeuristicsGasLimitEstimator):
    def __init__(self, message: any_pb2.Any):
        self._message = self._parsed_message(message=message)

    @classmethod
    def applies_to(cls, message: any_pb2.Any):
        return cls.message_type(message=message).endswith("MsgBatchCreateSpotLimitOrders")

    def gas_limit(self) -> int:
        total = 0

        for order in self._message.orders:
            total += CreateSpotLimitOrdersGasLimitEstimator.gas_cost_for_order(order)

        return total

    def _message_class(self, message: any_pb2.Any):
        return injective_exchange_tx_pb.MsgBatchCreateSpotLimitOrders


class BatchCancelSpotOrdersGasLimitEstimator(GasHeuristicsGasLimitEstimator):
    def __init__(self, message: any_pb2.Any):
        self._message = self._parsed_message(message=message)

    @classmethod
    def applies_to(cls, message: any_pb2.Any):
        return cls.message_type(message=message).endswith("MsgBatchCancelSpotOrders")

    def gas_limit(self) -> int:
        total = 0
        total += len(self._message.data) * SPOT_ORDER_CANCELATION_GAS_LIMIT

        return total

    def _message_class(self, message: any_pb2.Any):
        return injective_exchange_tx_pb.MsgBatchCancelSpotOrders


class BatchCreateDerivativeLimitOrdersGasLimitEstimator(GasHeuristicsGasLimitEstimator):
    def __init__(self, message: any_pb2.Any):
        self._message = self._parsed_message(message=message)

    @classmethod
    def applies_to(cls, message: any_pb2.Any):
        return cls.message_type(message=message).endswith("MsgBatchCreateDerivativeLimitOrders")

    def gas_limit(self) -> int:
        total = 0

        for order in self._message.orders:
            total += CreateDerivativeLimitOrdersGasLimitEstimator.gas_cost_for_order(order)

        return total

    def _message_class(self, message: any_pb2.Any):
        return injective_exchange_tx_pb.MsgBatchCreateDerivativeLimitOrders


class BatchCancelDerivativeOrdersGasLimitEstimator(GasHeuristicsGasLimitEstimator):
    def __init__(self, message: any_pb2.Any):
        self._message = self._parsed_message(message=message)

    @classmethod
    def applies_to(cls, message: any_pb2.Any):
        return cls.message_type(message=message).endswith("MsgBatchCancelDerivativeOrders")

    def gas_limit(self) -> int:
        total = 0
        total += len(self._message.data) * DERIVATIVE_ORDER_CANCELATION_GAS_LIMIT

        return total

    def _message_class(self, message: any_pb2.Any):
        return injective_exchange_tx_pb.MsgBatchCancelDerivativeOrders


class BatchUpdateOrdersGasLimitEstimator(GasHeuristicsGasLimitEstimator):
    AVERAGE_CANCEL_ALL_AFFECTED_ORDERS = 20

    def __init__(self, message: any_pb2.Any):
        self._message = self._parsed_message(message=message)

    @classmethod
    def applies_to(cls, message: any_pb2.Any):
        return cls.message_type(message=message).endswith("MsgBatchUpdateOrders")

    def gas_limit(self) -> int:
        total = 0

        for order in self._message.spot_orders_to_create:
            total += CreateSpotLimitOrdersGasLimitEstimator.gas_cost_for_order(order)
        for order in self._message.derivative_orders_to_create:
            total += CreateDerivativeLimitOrdersGasLimitEstimator.gas_cost_for_order(order)
        for order in self._message.binary_options_orders_to_create:
            total += CreateBinaryOptionsLimitOrdersGasLimitEstimator.gas_cost_for_order(order)

        total += len(self._message.spot_orders_to_cancel) * SPOT_ORDER_CANCELATION_GAS_LIMIT
        total += len(self._message.derivative_orders_to_cancel) * DERIVATIVE_ORDER_CANCELATION_GAS_LIMIT
        total += len(self._message.binary_options_orders_to_cancel) * BINARY_OPTIONS_ORDER_CANCELATION_GAS_LIMIT

        total += (
            len(self._message.spot_market_ids_to_cancel_all)
            * SPOT_ORDER_CANCELATION_GAS_LIMIT
            * self.AVERAGE_CANCEL_ALL_AFFECTED_ORDERS
        )
        total += (
            len(self._message.derivative_market_ids_to_cancel_all)
            * DERIVATIVE_ORDER_CANCELATION_GAS_LIMIT
            * self.AVERAGE_CANCEL_ALL_AFFECTED_ORDERS
        )
        total += (
            len(self._message.binary_options_market_ids_to_cancel_all)
            * BINARY_OPTIONS_ORDER_CANCELATION_GAS_LIMIT
            * self.AVERAGE_CANCEL_ALL_AFFECTED_ORDERS
        )

        return total

    def _message_class(self, message: any_pb2.Any):
        return injective_exchange_tx_pb.MsgBatchUpdateOrders


class DepositGasLimitEstimator(GasHeuristicsGasLimitEstimator):
    def __init__(self, message: any_pb2.Any):
        self._message = self._parsed_message(message=message)

    @classmethod
    def applies_to(cls, message: any_pb2.Any):
        message_type = cls.message_type(message=message)
        return ".exchange." in message_type and message_type.endswith("MsgDeposit")

    def gas_limit(self) -> int:
        return DEPOSIT_GAS_LIMIT

    def _message_class(self, message: any_pb2.Any):
        return injective_exchange_tx_pb.MsgDeposit


class WithdrawGasLimitEstimator(GasHeuristicsGasLimitEstimator):
    def __init__(self, message: any_pb2.Any):
        self._message = self._parsed_message(message=message)

    @classmethod
    def applies_to(cls, message: any_pb2.Any):
        message_type = cls.message_type(message=message)
        return ".exchange." in message_type and message_type.endswith("MsgWithdraw")

    def gas_limit(self) -> int:
        return WITHDRAW_GAS_LIMIT

    def _message_class(self, message: any_pb2.Any):
        return injective_exchange_tx_pb.MsgWithdraw


class SubaccountTransferGasLimitEstimator(GasHeuristicsGasLimitEstimator):
    def __init__(self, message: any_pb2.Any):
        self._message = self._parsed_message(message=message)

    @classmethod
    def applies_to(cls, message: any_pb2.Any):
        message_type = cls.message_type(message=message)
        return ".exchange." in message_type and message_type.endswith("MsgSubaccountTransfer")

    def gas_limit(self) -> int:
        return SUBACCOUNT_TRANSFER_GAS_LIMIT

    def _message_class(self, message: any_pb2.Any):
        return injective_exchange_tx_pb.MsgSubaccountTransfer


class ExternalTransferGasLimitEstimator(GasHeuristicsGasLimitEstimator):
    def __init__(self, message: any_pb2.Any):
        self._message = self._parsed_message(message=message)

    @classmethod
    def applies_to(cls, message: any_pb2.Any):
        message_type = cls.message_type(message=message)
        return ".exchange." in message_type and message_type.endswith("MsgExternalTransfer")

    def gas_limit(self) -> int:
        return EXTERNAL_TRANSFER_GAS_LIMIT

    def _message_class(self, message: any_pb2.Any):
        return injective_exchange_tx_pb.MsgExternalTransfer


class IncreasePositionMarginGasLimitEstimator(GasHeuristicsGasLimitEstimator):
    def __init__(self, message: any_pb2.Any):
        self._message = self._parsed_message(message=message)

    @classmethod
    def applies_to(cls, message: any_pb2.Any):
        message_type = cls.message_type(message=message)
        return ".exchange." in message_type and message_type.endswith("MsgIncreasePositionMargin")

    def gas_limit(self) -> int:
        return INCREASE_POSITION_MARGIN_TRANSFER_GAS_LIMIT

    def _message_class(self, message: any_pb2.Any):
        return injective_exchange_tx_pb.MsgIncreasePositionMargin


class DecreasePositionMarginGasLimitEstimator(GasHeuristicsGasLimitEstimator):
    def __init__(self, message: any_pb2.Any):
        self._message = self._parsed_message(message=message)

    @classmethod
    def applies_to(cls, message: any_pb2.Any):
        message_type = cls.message_type(message=message)
        return ".exchange." in message_type and message_type.endswith("MsgDecreasePositionMargin")

    def gas_limit(self) -> int:
        return DECREASE_POSITION_MARGIN_TRANSFER_GAS_LIMIT

    def _message_class(self, message: any_pb2.Any):
        return injective_exchange_tx_pb.MsgDecreasePositionMargin


class ExecGasLimitEstimator(GasHeuristicsGasLimitEstimator):
    DEFAULT_GAS_LIMIT = 20_000

    def __init__(self, message: any_pb2.Any):
        self._message = self._parsed_message(message=message)

    @classmethod
    def applies_to(cls, message: any_pb2.Any) -> bool:
        return cls.message_type(message=message).endswith("MsgExec")

    def gas_limit(self) -> int:
        total = sum(
            [
                GasHeuristicsGasLimitEstimator.for_message(message=inner_message).gas_limit()
                for inner_message in self._message.msgs
            ]
        )
        total += self.DEFAULT_GAS_LIMIT

        return total

    def _message_class(self, message: any_pb2.Any):
        return cosmos_authz_tx_pb.MsgExec



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cometbft/services/version/v1/version_service.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.cometbft.services.version.v1 import version_pb2 as cometbft_dot_services_dot_version_dot_v1_dot_version__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2cometbft/services/version/v1/version_service.proto\x12\x1c\x63ometbft.services.version.v1\x1a*cometbft/services/version/v1/version.proto2\x81\x01\n\x0eVersionService\x12o\n\nGetVersion\x12/.cometbft.services.version.v1.GetVersionRequest\x1a\x30.cometbft.services.version.v1.GetVersionResponseB\x89\x02\n com.cometbft.services.version.v1B\x13VersionServiceProtoP\x01Z=github.com/cometbft/cometbft/api/cometbft/services/version/v1\xa2\x02\x03\x43SV\xaa\x02\x1c\x43ometbft.Services.Version.V1\xca\x02\x1c\x43ometbft\\Services\\Version\\V1\xe2\x02(Cometbft\\Services\\Version\\V1\\GPBMetadata\xea\x02\x1f\x43ometbft::Services::Version::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cometbft.services.version.v1.version_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n com.cometbft.services.version.v1B\023VersionServiceProtoP\001Z=github.com/cometbft/cometbft/api/cometbft/services/version/v1\242\002\003CSV\252\002\034Cometbft.Services.Version.V1\312\002\034Cometbft\\Services\\Version\\V1\342\002(Cometbft\\Services\\Version\\V1\\GPBMetadata\352\002\037Cometbft::Services::Version::V1'
  _globals['_VERSIONSERVICE']._serialized_start=129
  _globals['_VERSIONSERVICE']._serialized_end=258
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: capability/v1/genesis.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from capability.v1 import capability_pb2 as capability_dot_v1_dot_capability__pb2
from pyinjective.proto.amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x63\x61pability/v1/genesis.proto\x12\rcapability.v1\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63\x61pability/v1/capability.proto\x1a\x11\x61mino/amino.proto\"t\n\rGenesisOwners\x12\x14\n\x05index\x18\x01 \x01(\x04R\x05index\x12M\n\x0cindex_owners\x18\x02 \x01(\x0b\x32\x1f.capability.v1.CapabilityOwnersB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\x0bindexOwners\"e\n\x0cGenesisState\x12\x14\n\x05index\x18\x01 \x01(\x04R\x05index\x12?\n\x06owners\x18\x02 \x03(\x0b\x32\x1c.capability.v1.GenesisOwnersB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\x06ownersB\xa9\x01\n\x11\x63om.capability.v1B\x0cGenesisProtoP\x01Z1github.com/cosmos/ibc-go/modules/capability/types\xa2\x02\x03\x43XX\xaa\x02\rCapability.V1\xca\x02\rCapability\\V1\xe2\x02\x19\x43\x61pability\\V1\\GPBMetadata\xea\x02\x0e\x43\x61pability::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'capability.v1.genesis_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\021com.capability.v1B\014GenesisProtoP\001Z1github.com/cosmos/ibc-go/modules/capability/types\242\002\003CXX\252\002\rCapability.V1\312\002\rCapability\\V1\342\002\031Capability\\V1\\GPBMetadata\352\002\016Capability::V1'
  _globals['_GENESISOWNERS'].fields_by_name['index_owners']._loaded_options = None
  _globals['_GENESISOWNERS'].fields_by_name['index_owners']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_GENESISSTATE'].fields_by_name['owners']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['owners']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_GENESISOWNERS']._serialized_start=119
  _globals['_GENESISOWNERS']._serialized_end=235
  _globals['_GENESISSTATE']._serialized_start=237
  _globals['_GENESISSTATE']._serialized_end=338
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/types/v1beta1/indexer.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%injective/types/v1beta1/indexer.proto\x12\x17injective.types.v1beta1\x1a\x14gogoproto/gogo.proto\"\xe5\x01\n\x08TxResult\x12\x16\n\x06height\x18\x01 \x01(\x03R\x06height\x12\x19\n\x08tx_index\x18\x02 \x01(\rR\x07txIndex\x12\x1b\n\tmsg_index\x18\x03 \x01(\rR\x08msgIndex\x12 \n\x0c\x65th_tx_index\x18\x04 \x01(\x05R\nethTxIndex\x12\x16\n\x06\x66\x61iled\x18\x05 \x01(\x08R\x06\x66\x61iled\x12\x19\n\x08gas_used\x18\x06 \x01(\x04R\x07gasUsed\x12.\n\x13\x63umulative_gas_used\x18\x07 \x01(\x04R\x11\x63umulativeGasUsed:\x04\x88\xa0\x1f\x00\x42\xe8\x01\n\x1b\x63om.injective.types.v1beta1B\x0cIndexerProtoP\x01Z=github.com/InjectiveLabs/injective-core/injective-chain/types\xa2\x02\x03ITX\xaa\x02\x17Injective.Types.V1beta1\xca\x02\x17Injective\\Types\\V1beta1\xe2\x02#Injective\\Types\\V1beta1\\GPBMetadata\xea\x02\x19Injective::Types::V1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.types.v1beta1.indexer_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033com.injective.types.v1beta1B\014IndexerProtoP\001Z=github.com/InjectiveLabs/injective-core/injective-chain/types\242\002\003ITX\252\002\027Injective.Types.V1beta1\312\002\027Injective\\Types\\V1beta1\342\002#Injective\\Types\\V1beta1\\GPBMetadata\352\002\031Injective::Types::V1beta1'
  _globals['_TXRESULT']._loaded_options = None
  _globals['_TXRESULT']._serialized_options = b'\210\240\037\000'
  _globals['_TXRESULT']._serialized_start=89
  _globals['_TXRESULT']._serialized_end=318
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from pyinjective.proto.exchange import health_pb2 as exchange_dot_health__pb2


class HealthStub(object):
    """HealthAPI allows to check if backend data is up-to-date and reliable or not.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetStatus = channel.unary_unary(
                '/api.v1.Health/GetStatus',
                request_serializer=exchange_dot_health__pb2.GetStatusRequest.SerializeToString,
                response_deserializer=exchange_dot_health__pb2.GetStatusResponse.FromString,
                _registered_method=True)


class HealthServicer(object):
    """HealthAPI allows to check if backend data is up-to-date and reliable or not.
    """

    def GetStatus(self, request, context):
        """Get current backend health status
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_HealthServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetStatus': grpc.unary_unary_rpc_method_handler(
                    servicer.GetStatus,
                    request_deserializer=exchange_dot_health__pb2.GetStatusRequest.FromString,
                    response_serializer=exchange_dot_health__pb2.GetStatusResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'api.v1.Health', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('api.v1.Health', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class Health(object):
    """HealthAPI allows to check if backend data is up-to-date and reliable or not.
    """

    @staticmethod
    def GetStatus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/api.v1.Health/GetStatus',
            exchange_dot_health__pb2.GetStatusRequest.SerializeToString,
            exchange_dot_health__pb2.GetStatusResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



from typing import Any, Callable, Dict

from google.protobuf import json_format

from pyinjective.core.network import CookieAssistant


class GrpcApiRequestAssistant:
    def __init__(self, cookie_assistant: CookieAssistant):
        super().__init__()
        self._cookie_assistant = cookie_assistant

    async def execute_call(self, call: Callable, request) -> Dict[str, Any]:
        metadata = self._cookie_assistant.metadata()
        grpc_call = call(request, metadata=metadata)
        response = await grpc_call

        await self._cookie_assistant.process_response_metadata(grpc_call=grpc_call)

        result = json_format.MessageToDict(
            message=response,
            always_print_fields_with_no_presence=True,
        )

        return result



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ibc/core/types/v1/genesis.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.ibc.core.client.v1 import genesis_pb2 as ibc_dot_core_dot_client_dot_v1_dot_genesis__pb2
from pyinjective.proto.ibc.core.connection.v1 import genesis_pb2 as ibc_dot_core_dot_connection_dot_v1_dot_genesis__pb2
from pyinjective.proto.ibc.core.channel.v1 import genesis_pb2 as ibc_dot_core_dot_channel_dot_v1_dot_genesis__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fibc/core/types/v1/genesis.proto\x12\x11ibc.core.types.v1\x1a\x14gogoproto/gogo.proto\x1a ibc/core/client/v1/genesis.proto\x1a$ibc/core/connection/v1/genesis.proto\x1a!ibc/core/channel/v1/genesis.proto\"\x8a\x02\n\x0cGenesisState\x12M\n\x0e\x63lient_genesis\x18\x01 \x01(\x0b\x32 .ibc.core.client.v1.GenesisStateB\x04\xc8\xde\x1f\x00R\rclientGenesis\x12Y\n\x12\x63onnection_genesis\x18\x02 \x01(\x0b\x32$.ibc.core.connection.v1.GenesisStateB\x04\xc8\xde\x1f\x00R\x11\x63onnectionGenesis\x12P\n\x0f\x63hannel_genesis\x18\x03 \x01(\x0b\x32!.ibc.core.channel.v1.GenesisStateB\x04\xc8\xde\x1f\x00R\x0e\x63hannelGenesisB\xbc\x01\n\x15\x63om.ibc.core.types.v1B\x0cGenesisProtoP\x01Z.github.com/cosmos/ibc-go/v8/modules/core/types\xa2\x02\x03ICT\xaa\x02\x11Ibc.Core.Types.V1\xca\x02\x11Ibc\\Core\\Types\\V1\xe2\x02\x1dIbc\\Core\\Types\\V1\\GPBMetadata\xea\x02\x14Ibc::Core::Types::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.core.types.v1.genesis_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\025com.ibc.core.types.v1B\014GenesisProtoP\001Z.github.com/cosmos/ibc-go/v8/modules/core/types\242\002\003ICT\252\002\021Ibc.Core.Types.V1\312\002\021Ibc\\Core\\Types\\V1\342\002\035Ibc\\Core\\Types\\V1\\GPBMetadata\352\002\024Ibc::Core::Types::V1'
  _globals['_GENESISSTATE'].fields_by_name['client_genesis']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['client_genesis']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE'].fields_by_name['connection_genesis']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['connection_genesis']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE'].fields_by_name['channel_genesis']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['channel_genesis']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE']._serialized_start=184
  _globals['_GENESISSTATE']._serialized_end=450
# @@protoc_insertion_point(module_scope)



from typing import Callable, List, Optional

from grpc.aio import Channel

from pyinjective.core.network import CookieAssistant
from pyinjective.proto.exchange import (
    injective_oracle_rpc_pb2 as exchange_oracle_pb,
    injective_oracle_rpc_pb2_grpc as exchange_oracle_grpc,
)
from pyinjective.utils.grpc_api_stream_assistant import GrpcApiStreamAssistant


class IndexerGrpcOracleStream:
    def __init__(self, channel: Channel, cookie_assistant: CookieAssistant):
        self._stub = self._stub = exchange_oracle_grpc.InjectiveOracleRPCStub(channel)
        self._assistant = GrpcApiStreamAssistant(cookie_assistant=cookie_assistant)

    async def stream_oracle_prices(
        self,
        callback: Callable,
        on_end_callback: Optional[Callable] = None,
        on_status_callback: Optional[Callable] = None,
        base_symbol: Optional[str] = None,
        quote_symbol: Optional[str] = None,
        oracle_type: Optional[str] = None,
    ):
        request = exchange_oracle_pb.StreamPricesRequest(
            base_symbol=base_symbol,
            quote_symbol=quote_symbol,
            oracle_type=oracle_type,
        )

        await self._assistant.listen_stream(
            call=self._stub.StreamPrices,
            request=request,
            callback=callback,
            on_end_callback=on_end_callback,
            on_status_callback=on_status_callback,
        )

    async def stream_oracle_prices_by_markets(
        self,
        market_ids: List[str],
        callback: Callable,
        on_end_callback: Optional[Callable] = None,
        on_status_callback: Optional[Callable] = None,
    ):
        request = exchange_oracle_pb.StreamPricesByMarketsRequest(
            market_ids=market_ids,
        )

        await self._assistant.listen_stream(
            call=self._stub.StreamPricesByMarkets,
            request=request,
            callback=callback,
            on_end_callback=on_end_callback,
            on_status_callback=on_status_callback,
        )



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/api/expr/v1alpha1/explain.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.google.api.expr.v1alpha1 import value_pb2 as google_dot_api_dot_expr_dot_v1alpha1_dot_value__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&google/api/expr/v1alpha1/explain.proto\x12\x18google.api.expr.v1alpha1\x1a$google/api/expr/v1alpha1/value.proto\"\xce\x01\n\x07\x45xplain\x12\x37\n\x06values\x18\x01 \x03(\x0b\x32\x1f.google.api.expr.v1alpha1.ValueR\x06values\x12I\n\nexpr_steps\x18\x02 \x03(\x0b\x32*.google.api.expr.v1alpha1.Explain.ExprStepR\texprSteps\x1a;\n\x08\x45xprStep\x12\x0e\n\x02id\x18\x01 \x01(\x03R\x02id\x12\x1f\n\x0bvalue_index\x18\x02 \x01(\x05R\nvalueIndex:\x02\x18\x01\x42\xf0\x01\n\x1c\x63om.google.api.expr.v1alpha1B\x0c\x45xplainProtoP\x01Z<google.golang.org/genproto/googleapis/api/expr/v1alpha1;expr\xf8\x01\x01\xa2\x02\x03GAE\xaa\x02\x18Google.Api.Expr.V1alpha1\xca\x02\x18Google\\Api\\Expr\\V1alpha1\xe2\x02$Google\\Api\\Expr\\V1alpha1\\GPBMetadata\xea\x02\x1bGoogle::Api::Expr::V1alpha1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.api.expr.v1alpha1.explain_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\034com.google.api.expr.v1alpha1B\014ExplainProtoP\001Z<google.golang.org/genproto/googleapis/api/expr/v1alpha1;expr\370\001\001\242\002\003GAE\252\002\030Google.Api.Expr.V1alpha1\312\002\030Google\\Api\\Expr\\V1alpha1\342\002$Google\\Api\\Expr\\V1alpha1\\GPBMetadata\352\002\033Google::Api::Expr::V1alpha1'
  _globals['_EXPLAIN']._loaded_options = None
  _globals['_EXPLAIN']._serialized_options = b'\030\001'
  _globals['_EXPLAIN']._serialized_start=107
  _globals['_EXPLAIN']._serialized_end=313
  _globals['_EXPLAIN_EXPRSTEP']._serialized_start=250
  _globals['_EXPLAIN_EXPRSTEP']._serialized_end=309
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cometbft/abci/v1/types.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.cometbft.crypto.v1 import proof_pb2 as cometbft_dot_crypto_dot_v1_dot_proof__pb2
from pyinjective.proto.cometbft.types.v1 import params_pb2 as cometbft_dot_types_dot_v1_dot_params__pb2
from pyinjective.proto.cometbft.types.v1 import validator_pb2 as cometbft_dot_types_dot_v1_dot_validator__pb2
from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x63ometbft/abci/v1/types.proto\x12\x10\x63ometbft.abci.v1\x1a\x1e\x63ometbft/crypto/v1/proof.proto\x1a\x1e\x63ometbft/types/v1/params.proto\x1a!cometbft/types/v1/validator.proto\x1a\x14gogoproto/gogo.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xcf\t\n\x07Request\x12\x33\n\x04\x65\x63ho\x18\x01 \x01(\x0b\x32\x1d.cometbft.abci.v1.EchoRequestH\x00R\x04\x65\x63ho\x12\x36\n\x05\x66lush\x18\x02 \x01(\x0b\x32\x1e.cometbft.abci.v1.FlushRequestH\x00R\x05\x66lush\x12\x33\n\x04info\x18\x03 \x01(\x0b\x32\x1d.cometbft.abci.v1.InfoRequestH\x00R\x04info\x12\x43\n\ninit_chain\x18\x05 \x01(\x0b\x32\".cometbft.abci.v1.InitChainRequestH\x00R\tinitChain\x12\x36\n\x05query\x18\x06 \x01(\x0b\x32\x1e.cometbft.abci.v1.QueryRequestH\x00R\x05query\x12=\n\x08\x63heck_tx\x18\x08 \x01(\x0b\x32 .cometbft.abci.v1.CheckTxRequestH\x00R\x07\x63heckTx\x12\x39\n\x06\x63ommit\x18\x0b \x01(\x0b\x32\x1f.cometbft.abci.v1.CommitRequestH\x00R\x06\x63ommit\x12O\n\x0elist_snapshots\x18\x0c \x01(\x0b\x32&.cometbft.abci.v1.ListSnapshotsRequestH\x00R\rlistSnapshots\x12O\n\x0eoffer_snapshot\x18\r \x01(\x0b\x32&.cometbft.abci.v1.OfferSnapshotRequestH\x00R\rofferSnapshot\x12\\\n\x13load_snapshot_chunk\x18\x0e \x01(\x0b\x32*.cometbft.abci.v1.LoadSnapshotChunkRequestH\x00R\x11loadSnapshotChunk\x12_\n\x14\x61pply_snapshot_chunk\x18\x0f \x01(\x0b\x32+.cometbft.abci.v1.ApplySnapshotChunkRequestH\x00R\x12\x61pplySnapshotChunk\x12U\n\x10prepare_proposal\x18\x10 \x01(\x0b\x32(.cometbft.abci.v1.PrepareProposalRequestH\x00R\x0fprepareProposal\x12U\n\x10process_proposal\x18\x11 \x01(\x0b\x32(.cometbft.abci.v1.ProcessProposalRequestH\x00R\x0fprocessProposal\x12\x46\n\x0b\x65xtend_vote\x18\x12 \x01(\x0b\x32#.cometbft.abci.v1.ExtendVoteRequestH\x00R\nextendVote\x12\x62\n\x15verify_vote_extension\x18\x13 \x01(\x0b\x32,.cometbft.abci.v1.VerifyVoteExtensionRequestH\x00R\x13verifyVoteExtension\x12O\n\x0e\x66inalize_block\x18\x14 \x01(\x0b\x32&.cometbft.abci.v1.FinalizeBlockRequestH\x00R\rfinalizeBlockB\x07\n\x05valueJ\x04\x08\x04\x10\x05J\x04\x08\x07\x10\x08J\x04\x08\t\x10\nJ\x04\x08\n\x10\x0b\"\'\n\x0b\x45\x63hoRequest\x12\x18\n\x07message\x18\x01 \x01(\tR\x07message\"\x0e\n\x0c\x46lushRequest\"\x90\x01\n\x0bInfoRequest\x12\x18\n\x07version\x18\x01 \x01(\tR\x07version\x12#\n\rblock_version\x18\x02 \x01(\x04R\x0c\x62lockVersion\x12\x1f\n\x0bp2p_version\x18\x03 \x01(\x04R\np2pVersion\x12!\n\x0c\x61\x62\x63i_version\x18\x04 \x01(\tR\x0b\x61\x62\x63iVersion\"\xce\x02\n\x10InitChainRequest\x12\x38\n\x04time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01R\x04time\x12\x19\n\x08\x63hain_id\x18\x02 \x01(\tR\x07\x63hainId\x12M\n\x10\x63onsensus_params\x18\x03 \x01(\x0b\x32\".cometbft.types.v1.ConsensusParamsR\x0f\x63onsensusParams\x12G\n\nvalidators\x18\x04 \x03(\x0b\x32!.cometbft.abci.v1.ValidatorUpdateB\x04\xc8\xde\x1f\x00R\nvalidators\x12&\n\x0f\x61pp_state_bytes\x18\x05 \x01(\x0cR\rappStateBytes\x12%\n\x0einitial_height\x18\x06 \x01(\x03R\rinitialHeight\"d\n\x0cQueryRequest\x12\x12\n\x04\x64\x61ta\x18\x01 \x01(\x0cR\x04\x64\x61ta\x12\x12\n\x04path\x18\x02 \x01(\tR\x04path\x12\x16\n\x06height\x18\x03 \x01(\x03R\x06height\x12\x14\n\x05prove\x18\x04 \x01(\x08R\x05prove\"Y\n\x0e\x43heckTxRequest\x12\x0e\n\x02tx\x18\x01 \x01(\x0cR\x02tx\x12\x31\n\x04type\x18\x03 \x01(\x0e\x32\x1d.cometbft.abci.v1.CheckTxTypeR\x04typeJ\x04\x08\x02\x10\x03\"\x0f\n\rCommitRequest\"\x16\n\x14ListSnapshotsRequest\"i\n\x14OfferSnapshotRequest\x12\x36\n\x08snapshot\x18\x01 \x01(\x0b\x32\x1a.cometbft.abci.v1.SnapshotR\x08snapshot\x12\x19\n\x08\x61pp_hash\x18\x02 \x01(\x0cR\x07\x61ppHash\"`\n\x18LoadSnapshotChunkRequest\x12\x16\n\x06height\x18\x01 \x01(\x04R\x06height\x12\x16\n\x06\x66ormat\x18\x02 \x01(\rR\x06\x66ormat\x12\x14\n\x05\x63hunk\x18\x03 \x01(\rR\x05\x63hunk\"_\n\x19\x41pplySnapshotChunkRequest\x12\x14\n\x05index\x18\x01 \x01(\rR\x05index\x12\x14\n\x05\x63hunk\x18\x02 \x01(\x0cR\x05\x63hunk\x12\x16\n\x06sender\x18\x03 \x01(\tR\x06sender\"\x9a\x03\n\x16PrepareProposalRequest\x12 \n\x0cmax_tx_bytes\x18\x01 \x01(\x03R\nmaxTxBytes\x12\x10\n\x03txs\x18\x02 \x03(\x0cR\x03txs\x12V\n\x11local_last_commit\x18\x03 \x01(\x0b\x32$.cometbft.abci.v1.ExtendedCommitInfoB\x04\xc8\xde\x1f\x00R\x0flocalLastCommit\x12\x45\n\x0bmisbehavior\x18\x04 \x03(\x0b\x32\x1d.cometbft.abci.v1.MisbehaviorB\x04\xc8\xde\x1f\x00R\x0bmisbehavior\x12\x16\n\x06height\x18\x05 \x01(\x03R\x06height\x12\x38\n\x04time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01R\x04time\x12\x30\n\x14next_validators_hash\x18\x07 \x01(\x0cR\x12nextValidatorsHash\x12)\n\x10proposer_address\x18\x08 \x01(\x0cR\x0fproposerAddress\"\x8a\x03\n\x16ProcessProposalRequest\x12\x10\n\x03txs\x18\x01 \x03(\x0cR\x03txs\x12T\n\x14proposed_last_commit\x18\x02 \x01(\x0b\x32\x1c.cometbft.abci.v1.CommitInfoB\x04\xc8\xde\x1f\x00R\x12proposedLastCommit\x12\x45\n\x0bmisbehavior\x18\x03 \x03(\x0b\x32\x1d.cometbft.abci.v1.MisbehaviorB\x04\xc8\xde\x1f\x00R\x0bmisbehavior\x12\x12\n\x04hash\x18\x04 \x01(\x0cR\x04hash\x12\x16\n\x06height\x18\x05 \x01(\x03R\x06height\x12\x38\n\x04time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01R\x04time\x12\x30\n\x14next_validators_hash\x18\x07 \x01(\x0cR\x12nextValidatorsHash\x12)\n\x10proposer_address\x18\x08 \x01(\x0cR\x0fproposerAddress\"\x85\x03\n\x11\x45xtendVoteRequest\x12\x12\n\x04hash\x18\x01 \x01(\x0cR\x04hash\x12\x16\n\x06height\x18\x02 \x01(\x03R\x06height\x12\x38\n\x04time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01R\x04time\x12\x10\n\x03txs\x18\x04 \x03(\x0cR\x03txs\x12T\n\x14proposed_last_commit\x18\x05 \x01(\x0b\x32\x1c.cometbft.abci.v1.CommitInfoB\x04\xc8\xde\x1f\x00R\x12proposedLastCommit\x12\x45\n\x0bmisbehavior\x18\x06 \x03(\x0b\x32\x1d.cometbft.abci.v1.MisbehaviorB\x04\xc8\xde\x1f\x00R\x0bmisbehavior\x12\x30\n\x14next_validators_hash\x18\x07 \x01(\x0cR\x12nextValidatorsHash\x12)\n\x10proposer_address\x18\x08 \x01(\x0cR\x0fproposerAddress\"\x9c\x01\n\x1aVerifyVoteExtensionRequest\x12\x12\n\x04hash\x18\x01 \x01(\x0cR\x04hash\x12+\n\x11validator_address\x18\x02 \x01(\x0cR\x10validatorAddress\x12\x16\n\x06height\x18\x03 \x01(\x03R\x06height\x12%\n\x0evote_extension\x18\x04 \x01(\x0cR\rvoteExtension\"\xb2\x03\n\x14\x46inalizeBlockRequest\x12\x10\n\x03txs\x18\x01 \x03(\x0cR\x03txs\x12R\n\x13\x64\x65\x63ided_last_commit\x18\x02 \x01(\x0b\x32\x1c.cometbft.abci.v1.CommitInfoB\x04\xc8\xde\x1f\x00R\x11\x64\x65\x63idedLastCommit\x12\x45\n\x0bmisbehavior\x18\x03 \x03(\x0b\x32\x1d.cometbft.abci.v1.MisbehaviorB\x04\xc8\xde\x1f\x00R\x0bmisbehavior\x12\x12\n\x04hash\x18\x04 \x01(\x0cR\x04hash\x12\x16\n\x06height\x18\x05 \x01(\x03R\x06height\x12\x38\n\x04time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01R\x04time\x12\x30\n\x14next_validators_hash\x18\x07 \x01(\x0cR\x12nextValidatorsHash\x12)\n\x10proposer_address\x18\x08 \x01(\x0cR\x0fproposerAddress\x12*\n\x11syncing_to_height\x18\t \x01(\x03R\x0fsyncingToHeight\"\xa5\n\n\x08Response\x12\x43\n\texception\x18\x01 \x01(\x0b\x32#.cometbft.abci.v1.ExceptionResponseH\x00R\texception\x12\x34\n\x04\x65\x63ho\x18\x02 \x01(\x0b\x32\x1e.cometbft.abci.v1.EchoResponseH\x00R\x04\x65\x63ho\x12\x37\n\x05\x66lush\x18\x03 \x01(\x0b\x32\x1f.cometbft.abci.v1.FlushResponseH\x00R\x05\x66lush\x12\x34\n\x04info\x18\x04 \x01(\x0b\x32\x1e.cometbft.abci.v1.InfoResponseH\x00R\x04info\x12\x44\n\ninit_chain\x18\x06 \x01(\x0b\x32#.cometbft.abci.v1.InitChainResponseH\x00R\tinitChain\x12\x37\n\x05query\x18\x07 \x01(\x0b\x32\x1f.cometbft.abci.v1.QueryResponseH\x00R\x05query\x12>\n\x08\x63heck_tx\x18\t \x01(\x0b\x32!.cometbft.abci.v1.CheckTxResponseH\x00R\x07\x63heckTx\x12:\n\x06\x63ommit\x18\x0c \x01(\x0b\x32 .cometbft.abci.v1.CommitResponseH\x00R\x06\x63ommit\x12P\n\x0elist_snapshots\x18\r \x01(\x0b\x32\'.cometbft.abci.v1.ListSnapshotsResponseH\x00R\rlistSnapshots\x12P\n\x0eoffer_snapshot\x18\x0e \x01(\x0b\x32\'.cometbft.abci.v1.OfferSnapshotResponseH\x00R\rofferSnapshot\x12]\n\x13load_snapshot_chunk\x18\x0f \x01(\x0b\x32+.cometbft.abci.v1.LoadSnapshotChunkResponseH\x00R\x11loadSnapshotChunk\x12`\n\x14\x61pply_snapshot_chunk\x18\x10 \x01(\x0b\x32,.cometbft.abci.v1.ApplySnapshotChunkResponseH\x00R\x12\x61pplySnapshotChunk\x12V\n\x10prepare_proposal\x18\x11 \x01(\x0b\x32).cometbft.abci.v1.PrepareProposalResponseH\x00R\x0fprepareProposal\x12V\n\x10process_proposal\x18\x12 \x01(\x0b\x32).cometbft.abci.v1.ProcessProposalResponseH\x00R\x0fprocessProposal\x12G\n\x0b\x65xtend_vote\x18\x13 \x01(\x0b\x32$.cometbft.abci.v1.ExtendVoteResponseH\x00R\nextendVote\x12\x63\n\x15verify_vote_extension\x18\x14 \x01(\x0b\x32-.cometbft.abci.v1.VerifyVoteExtensionResponseH\x00R\x13verifyVoteExtension\x12P\n\x0e\x66inalize_block\x18\x15 \x01(\x0b\x32\'.cometbft.abci.v1.FinalizeBlockResponseH\x00R\rfinalizeBlockB\x07\n\x05valueJ\x04\x08\x05\x10\x06J\x04\x08\x08\x10\tJ\x04\x08\n\x10\x0bJ\x04\x08\x0b\x10\x0c\")\n\x11\x45xceptionResponse\x12\x14\n\x05\x65rror\x18\x01 \x01(\tR\x05\x65rror\"(\n\x0c\x45\x63hoResponse\x12\x18\n\x07message\x18\x01 \x01(\tR\x07message\"\x0f\n\rFlushResponse\"\xfb\x02\n\x0cInfoResponse\x12\x12\n\x04\x64\x61ta\x18\x01 \x01(\tR\x04\x64\x61ta\x12\x18\n\x07version\x18\x02 \x01(\tR\x07version\x12\x1f\n\x0b\x61pp_version\x18\x03 \x01(\x04R\nappVersion\x12*\n\x11last_block_height\x18\x04 \x01(\x03R\x0flastBlockHeight\x12-\n\x13last_block_app_hash\x18\x05 \x01(\x0cR\x10lastBlockAppHash\x12[\n\x0flane_priorities\x18\x06 \x03(\x0b\x32\x32.cometbft.abci.v1.InfoResponse.LanePrioritiesEntryR\x0elanePriorities\x12!\n\x0c\x64\x65\x66\x61ult_lane\x18\x07 \x01(\tR\x0b\x64\x65\x66\x61ultLane\x1a\x41\n\x13LanePrioritiesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\rR\x05value:\x02\x38\x01\"\xc6\x01\n\x11InitChainResponse\x12M\n\x10\x63onsensus_params\x18\x01 \x01(\x0b\x32\".cometbft.types.v1.ConsensusParamsR\x0f\x63onsensusParams\x12G\n\nvalidators\x18\x02 \x03(\x0b\x32!.cometbft.abci.v1.ValidatorUpdateB\x04\xc8\xde\x1f\x00R\nvalidators\x12\x19\n\x08\x61pp_hash\x18\x03 \x01(\x0cR\x07\x61ppHash\"\xf8\x01\n\rQueryResponse\x12\x12\n\x04\x63ode\x18\x01 \x01(\rR\x04\x63ode\x12\x10\n\x03log\x18\x03 \x01(\tR\x03log\x12\x12\n\x04info\x18\x04 \x01(\tR\x04info\x12\x14\n\x05index\x18\x05 \x01(\x03R\x05index\x12\x10\n\x03key\x18\x06 \x01(\x0cR\x03key\x12\x14\n\x05value\x18\x07 \x01(\x0cR\x05value\x12\x39\n\tproof_ops\x18\x08 \x01(\x0b\x32\x1c.cometbft.crypto.v1.ProofOpsR\x08proofOps\x12\x16\n\x06height\x18\t \x01(\x03R\x06height\x12\x1c\n\tcodespace\x18\n \x01(\tR\tcodespace\"\xc4\x02\n\x0f\x43heckTxResponse\x12\x12\n\x04\x63ode\x18\x01 \x01(\rR\x04\x63ode\x12\x12\n\x04\x64\x61ta\x18\x02 \x01(\x0cR\x04\x64\x61ta\x12\x10\n\x03log\x18\x03 \x01(\tR\x03log\x12\x12\n\x04info\x18\x04 \x01(\tR\x04info\x12\x1e\n\ngas_wanted\x18\x05 \x01(\x03R\ngas_wanted\x12\x1a\n\x08gas_used\x18\x06 \x01(\x03R\x08gas_used\x12I\n\x06\x65vents\x18\x07 \x03(\x0b\x32\x17.cometbft.abci.v1.EventB\x18\xc8\xde\x1f\x00\xea\xde\x1f\x10\x65vents,omitemptyR\x06\x65vents\x12\x1c\n\tcodespace\x18\x08 \x01(\tR\tcodespace\x12\x17\n\x07lane_id\x18\x0c \x01(\tR\x06laneIdJ\x04\x08\t\x10\x0cR\x06senderR\x08priorityR\rmempool_error\"A\n\x0e\x43ommitResponse\x12#\n\rretain_height\x18\x03 \x01(\x03R\x0cretainHeightJ\x04\x08\x01\x10\x02J\x04\x08\x02\x10\x03\"Q\n\x15ListSnapshotsResponse\x12\x38\n\tsnapshots\x18\x01 \x03(\x0b\x32\x1a.cometbft.abci.v1.SnapshotR\tsnapshots\"V\n\x15OfferSnapshotResponse\x12=\n\x06result\x18\x01 \x01(\x0e\x32%.cometbft.abci.v1.OfferSnapshotResultR\x06result\"1\n\x19LoadSnapshotChunkResponse\x12\x14\n\x05\x63hunk\x18\x01 \x01(\x0cR\x05\x63hunk\"\xae\x01\n\x1a\x41pplySnapshotChunkResponse\x12\x42\n\x06result\x18\x01 \x01(\x0e\x32*.cometbft.abci.v1.ApplySnapshotChunkResultR\x06result\x12%\n\x0erefetch_chunks\x18\x02 \x03(\rR\rrefetchChunks\x12%\n\x0ereject_senders\x18\x03 \x03(\tR\rrejectSenders\"+\n\x17PrepareProposalResponse\x12\x10\n\x03txs\x18\x01 \x03(\x0cR\x03txs\"Z\n\x17ProcessProposalResponse\x12?\n\x06status\x18\x01 \x01(\x0e\x32\'.cometbft.abci.v1.ProcessProposalStatusR\x06status\";\n\x12\x45xtendVoteResponse\x12%\n\x0evote_extension\x18\x01 \x01(\x0cR\rvoteExtension\"b\n\x1bVerifyVoteExtensionResponse\x12\x43\n\x06status\x18\x01 \x01(\x0e\x32+.cometbft.abci.v1.VerifyVoteExtensionStatusR\x06status\"\xee\x02\n\x15\x46inalizeBlockResponse\x12I\n\x06\x65vents\x18\x01 \x03(\x0b\x32\x17.cometbft.abci.v1.EventB\x18\xc8\xde\x1f\x00\xea\xde\x1f\x10\x65vents,omitemptyR\x06\x65vents\x12=\n\ntx_results\x18\x02 \x03(\x0b\x32\x1e.cometbft.abci.v1.ExecTxResultR\ttxResults\x12T\n\x11validator_updates\x18\x03 \x03(\x0b\x32!.cometbft.abci.v1.ValidatorUpdateB\x04\xc8\xde\x1f\x00R\x10validatorUpdates\x12Z\n\x17\x63onsensus_param_updates\x18\x04 \x01(\x0b\x32\".cometbft.types.v1.ConsensusParamsR\x15\x63onsensusParamUpdates\x12\x19\n\x08\x61pp_hash\x18\x05 \x01(\x0cR\x07\x61ppHash\"Z\n\nCommitInfo\x12\x14\n\x05round\x18\x01 \x01(\x05R\x05round\x12\x36\n\x05votes\x18\x02 \x03(\x0b\x32\x1a.cometbft.abci.v1.VoteInfoB\x04\xc8\xde\x1f\x00R\x05votes\"j\n\x12\x45xtendedCommitInfo\x12\x14\n\x05round\x18\x01 \x01(\x05R\x05round\x12>\n\x05votes\x18\x02 \x03(\x0b\x32\".cometbft.abci.v1.ExtendedVoteInfoB\x04\xc8\xde\x1f\x00R\x05votes\"{\n\x05\x45vent\x12\x12\n\x04type\x18\x01 \x01(\tR\x04type\x12^\n\nattributes\x18\x02 \x03(\x0b\x32 .cometbft.abci.v1.EventAttributeB\x1c\xc8\xde\x1f\x00\xea\xde\x1f\x14\x61ttributes,omitemptyR\nattributes\"N\n\x0e\x45ventAttribute\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value\x12\x14\n\x05index\x18\x03 \x01(\x08R\x05index\"\x81\x02\n\x0c\x45xecTxResult\x12\x12\n\x04\x63ode\x18\x01 \x01(\rR\x04\x63ode\x12\x12\n\x04\x64\x61ta\x18\x02 \x01(\x0cR\x04\x64\x61ta\x12\x10\n\x03log\x18\x03 \x01(\tR\x03log\x12\x12\n\x04info\x18\x04 \x01(\tR\x04info\x12\x1e\n\ngas_wanted\x18\x05 \x01(\x03R\ngas_wanted\x12\x1a\n\x08gas_used\x18\x06 \x01(\x03R\x08gas_used\x12I\n\x06\x65vents\x18\x07 \x03(\x0b\x32\x17.cometbft.abci.v1.EventB\x18\xc8\xde\x1f\x00\xea\xde\x1f\x10\x65vents,omitemptyR\x06\x65vents\x12\x1c\n\tcodespace\x18\x08 \x01(\tR\tcodespace\"\x86\x01\n\x08TxResult\x12\x16\n\x06height\x18\x01 \x01(\x03R\x06height\x12\x14\n\x05index\x18\x02 \x01(\rR\x05index\x12\x0e\n\x02tx\x18\x03 \x01(\x0cR\x02tx\x12<\n\x06result\x18\x04 \x01(\x0b\x32\x1e.cometbft.abci.v1.ExecTxResultB\x04\xc8\xde\x1f\x00R\x06result\";\n\tValidator\x12\x18\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0cR\x07\x61\x64\x64ress\x12\x14\n\x05power\x18\x03 \x01(\x03R\x05power\"s\n\x0fValidatorUpdate\x12\x14\n\x05power\x18\x02 \x01(\x03R\x05power\x12\"\n\rpub_key_bytes\x18\x03 \x01(\x0cR\x0bpubKeyBytes\x12 \n\x0cpub_key_type\x18\x04 \x01(\tR\npubKeyTypeJ\x04\x08\x01\x10\x02\"\x95\x01\n\x08VoteInfo\x12?\n\tvalidator\x18\x01 \x01(\x0b\x32\x1b.cometbft.abci.v1.ValidatorB\x04\xc8\xde\x1f\x00R\tvalidator\x12\x42\n\rblock_id_flag\x18\x03 \x01(\x0e\x32\x1e.cometbft.types.v1.BlockIDFlagR\x0b\x62lockIdFlagJ\x04\x08\x02\x10\x03\"\xf5\x01\n\x10\x45xtendedVoteInfo\x12?\n\tvalidator\x18\x01 \x01(\x0b\x32\x1b.cometbft.abci.v1.ValidatorB\x04\xc8\xde\x1f\x00R\tvalidator\x12%\n\x0evote_extension\x18\x03 \x01(\x0cR\rvoteExtension\x12/\n\x13\x65xtension_signature\x18\x04 \x01(\x0cR\x12\x65xtensionSignature\x12\x42\n\rblock_id_flag\x18\x05 \x01(\x0e\x32\x1e.cometbft.types.v1.BlockIDFlagR\x0b\x62lockIdFlagJ\x04\x08\x02\x10\x03\"\x85\x02\n\x0bMisbehavior\x12\x35\n\x04type\x18\x01 \x01(\x0e\x32!.cometbft.abci.v1.MisbehaviorTypeR\x04type\x12?\n\tvalidator\x18\x02 \x01(\x0b\x32\x1b.cometbft.abci.v1.ValidatorB\x04\xc8\xde\x1f\x00R\tvalidator\x12\x16\n\x06height\x18\x03 \x01(\x03R\x06height\x12\x38\n\x04time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01R\x04time\x12,\n\x12total_voting_power\x18\x05 \x01(\x03R\x10totalVotingPower\"\x82\x01\n\x08Snapshot\x12\x16\n\x06height\x18\x01 \x01(\x04R\x06height\x12\x16\n\x06\x66ormat\x18\x02 \x01(\rR\x06\x66ormat\x12\x16\n\x06\x63hunks\x18\x03 \x01(\rR\x06\x63hunks\x12\x12\n\x04hash\x18\x04 \x01(\x0cR\x04hash\x12\x1a\n\x08metadata\x18\x05 \x01(\x0cR\x08metadata*b\n\x0b\x43heckTxType\x12\x19\n\x15\x43HECK_TX_TYPE_UNKNOWN\x10\x00\x12\x19\n\x15\x43HECK_TX_TYPE_RECHECK\x10\x01\x12\x17\n\x13\x43HECK_TX_TYPE_CHECK\x10\x02\x1a\x04\x88\xa3\x1e\x00*\xf5\x01\n\x13OfferSnapshotResult\x12!\n\x1dOFFER_SNAPSHOT_RESULT_UNKNOWN\x10\x00\x12 \n\x1cOFFER_SNAPSHOT_RESULT_ACCEPT\x10\x01\x12\x1f\n\x1bOFFER_SNAPSHOT_RESULT_ABORT\x10\x02\x12 \n\x1cOFFER_SNAPSHOT_RESULT_REJECT\x10\x03\x12\'\n#OFFER_SNAPSHOT_RESULT_REJECT_FORMAT\x10\x04\x12\'\n#OFFER_SNAPSHOT_RESULT_REJECT_SENDER\x10\x05\x1a\x04\x88\xa3\x1e\x00*\xa0\x02\n\x18\x41pplySnapshotChunkResult\x12\'\n#APPLY_SNAPSHOT_CHUNK_RESULT_UNKNOWN\x10\x00\x12&\n\"APPLY_SNAPSHOT_CHUNK_RESULT_ACCEPT\x10\x01\x12%\n!APPLY_SNAPSHOT_CHUNK_RESULT_ABORT\x10\x02\x12%\n!APPLY_SNAPSHOT_CHUNK_RESULT_RETRY\x10\x03\x12.\n*APPLY_SNAPSHOT_CHUNK_RESULT_RETRY_SNAPSHOT\x10\x04\x12/\n+APPLY_SNAPSHOT_CHUNK_RESULT_REJECT_SNAPSHOT\x10\x05\x1a\x04\x88\xa3\x1e\x00*\x8a\x01\n\x15ProcessProposalStatus\x12#\n\x1fPROCESS_PROPOSAL_STATUS_UNKNOWN\x10\x00\x12\"\n\x1ePROCESS_PROPOSAL_STATUS_ACCEPT\x10\x01\x12\"\n\x1ePROCESS_PROPOSAL_STATUS_REJECT\x10\x02\x1a\x04\x88\xa3\x1e\x00*\x9d\x01\n\x19VerifyVoteExtensionStatus\x12(\n$VERIFY_VOTE_EXTENSION_STATUS_UNKNOWN\x10\x00\x12\'\n#VERIFY_VOTE_EXTENSION_STATUS_ACCEPT\x10\x01\x12\'\n#VERIFY_VOTE_EXTENSION_STATUS_REJECT\x10\x02\x1a\x04\x88\xa3\x1e\x00*\x84\x01\n\x0fMisbehaviorType\x12\x1c\n\x18MISBEHAVIOR_TYPE_UNKNOWN\x10\x00\x12#\n\x1fMISBEHAVIOR_TYPE_DUPLICATE_VOTE\x10\x01\x12(\n$MISBEHAVIOR_TYPE_LIGHT_CLIENT_ATTACK\x10\x02\x1a\x04\x88\xa3\x1e\x00\x42\xb7\x01\n\x14\x63om.cometbft.abci.v1B\nTypesProtoP\x01Z1github.com/cometbft/cometbft/api/cometbft/abci/v1\xa2\x02\x03\x43\x41X\xaa\x02\x10\x43ometbft.Abci.V1\xca\x02\x10\x43ometbft\\Abci\\V1\xe2\x02\x1c\x43ometbft\\Abci\\V1\\GPBMetadata\xea\x02\x12\x43ometbft::Abci::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cometbft.abci.v1.types_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\024com.cometbft.abci.v1B\nTypesProtoP\001Z1github.com/cometbft/cometbft/api/cometbft/abci/v1\242\002\003CAX\252\002\020Cometbft.Abci.V1\312\002\020Cometbft\\Abci\\V1\342\002\034Cometbft\\Abci\\V1\\GPBMetadata\352\002\022Cometbft::Abci::V1'
  _globals['_CHECKTXTYPE']._loaded_options = None
  _globals['_CHECKTXTYPE']._serialized_options = b'\210\243\036\000'
  _globals['_OFFERSNAPSHOTRESULT']._loaded_options = None
  _globals['_OFFERSNAPSHOTRESULT']._serialized_options = b'\210\243\036\000'
  _globals['_APPLYSNAPSHOTCHUNKRESULT']._loaded_options = None
  _globals['_APPLYSNAPSHOTCHUNKRESULT']._serialized_options = b'\210\243\036\000'
  _globals['_PROCESSPROPOSALSTATUS']._loaded_options = None
  _globals['_PROCESSPROPOSALSTATUS']._serialized_options = b'\210\243\036\000'
  _globals['_VERIFYVOTEEXTENSIONSTATUS']._loaded_options = None
  _globals['_VERIFYVOTEEXTENSIONSTATUS']._serialized_options = b'\210\243\036\000'
  _globals['_MISBEHAVIORTYPE']._loaded_options = None
  _globals['_MISBEHAVIORTYPE']._serialized_options = b'\210\243\036\000'
  _globals['_INITCHAINREQUEST'].fields_by_name['time']._loaded_options = None
  _globals['_INITCHAINREQUEST'].fields_by_name['time']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _globals['_INITCHAINREQUEST'].fields_by_name['validators']._loaded_options = None
  _globals['_INITCHAINREQUEST'].fields_by_name['validators']._serialized_options = b'\310\336\037\000'
  _globals['_PREPAREPROPOSALREQUEST'].fields_by_name['local_last_commit']._loaded_options = None
  _globals['_PREPAREPROPOSALREQUEST'].fields_by_name['local_last_commit']._serialized_options = b'\310\336\037\000'
  _globals['_PREPAREPROPOSALREQUEST'].fields_by_name['misbehavior']._loaded_options = None
  _globals['_PREPAREPROPOSALREQUEST'].fields_by_name['misbehavior']._serialized_options = b'\310\336\037\000'
  _globals['_PREPAREPROPOSALREQUEST'].fields_by_name['time']._loaded_options = None
  _globals['_PREPAREPROPOSALREQUEST'].fields_by_name['time']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _globals['_PROCESSPROPOSALREQUEST'].fields_by_name['proposed_last_commit']._loaded_options = None
  _globals['_PROCESSPROPOSALREQUEST'].fields_by_name['proposed_last_commit']._serialized_options = b'\310\336\037\000'
  _globals['_PROCESSPROPOSALREQUEST'].fields_by_name['misbehavior']._loaded_options = None
  _globals['_PROCESSPROPOSALREQUEST'].fields_by_name['misbehavior']._serialized_options = b'\310\336\037\000'
  _globals['_PROCESSPROPOSALREQUEST'].fields_by_name['time']._loaded_options = None
  _globals['_PROCESSPROPOSALREQUEST'].fields_by_name['time']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _globals['_EXTENDVOTEREQUEST'].fields_by_name['time']._loaded_options = None
  _globals['_EXTENDVOTEREQUEST'].fields_by_name['time']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _globals['_EXTENDVOTEREQUEST'].fields_by_name['proposed_last_commit']._loaded_options = None
  _globals['_EXTENDVOTEREQUEST'].fields_by_name['proposed_last_commit']._serialized_options = b'\310\336\037\000'
  _globals['_EXTENDVOTEREQUEST'].fields_by_name['misbehavior']._loaded_options = None
  _globals['_EXTENDVOTEREQUEST'].fields_by_name['misbehavior']._serialized_options = b'\310\336\037\000'
  _globals['_FINALIZEBLOCKREQUEST'].fields_by_name['decided_last_commit']._loaded_options = None
  _globals['_FINALIZEBLOCKREQUEST'].fields_by_name['decided_last_commit']._serialized_options = b'\310\336\037\000'
  _globals['_FINALIZEBLOCKREQUEST'].fields_by_name['misbehavior']._loaded_options = None
  _globals['_FINALIZEBLOCKREQUEST'].fields_by_name['misbehavior']._serialized_options = b'\310\336\037\000'
  _globals['_FINALIZEBLOCKREQUEST'].fields_by_name['time']._loaded_options = None
  _globals['_FINALIZEBLOCKREQUEST'].fields_by_name['time']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _globals['_INFORESPONSE_LANEPRIORITIESENTRY']._loaded_options = None
  _globals['_INFORESPONSE_LANEPRIORITIESENTRY']._serialized_options = b'8\001'
  _globals['_INITCHAINRESPONSE'].fields_by_name['validators']._loaded_options = None
  _globals['_INITCHAINRESPONSE'].fields_by_name['validators']._serialized_options = b'\310\336\037\000'
  _globals['_CHECKTXRESPONSE'].fields_by_name['events']._loaded_options = None
  _globals['_CHECKTXRESPONSE'].fields_by_name['events']._serialized_options = b'\310\336\037\000\352\336\037\020events,omitempty'
  _globals['_FINALIZEBLOCKRESPONSE'].fields_by_name['events']._loaded_options = None
  _globals['_FINALIZEBLOCKRESPONSE'].fields_by_name['events']._serialized_options = b'\310\336\037\000\352\336\037\020events,omitempty'
  _globals['_FINALIZEBLOCKRESPONSE'].fields_by_name['validator_updates']._loaded_options = None
  _globals['_FINALIZEBLOCKRESPONSE'].fields_by_name['validator_updates']._serialized_options = b'\310\336\037\000'
  _globals['_COMMITINFO'].fields_by_name['votes']._loaded_options = None
  _globals['_COMMITINFO'].fields_by_name['votes']._serialized_options = b'\310\336\037\000'
  _globals['_EXTENDEDCOMMITINFO'].fields_by_name['votes']._loaded_options = None
  _globals['_EXTENDEDCOMMITINFO'].fields_by_name['votes']._serialized_options = b'\310\336\037\000'
  _globals['_EVENT'].fields_by_name['attributes']._loaded_options = None
  _globals['_EVENT'].fields_by_name['attributes']._serialized_options = b'\310\336\037\000\352\336\037\024attributes,omitempty'
  _globals['_EXECTXRESULT'].fields_by_name['events']._loaded_options = None
  _globals['_EXECTXRESULT'].fields_by_name['events']._serialized_options = b'\310\336\037\000\352\336\037\020events,omitempty'
  _globals['_TXRESULT'].fields_by_name['result']._loaded_options = None
  _globals['_TXRESULT'].fields_by_name['result']._serialized_options = b'\310\336\037\000'
  _globals['_VOTEINFO'].fields_by_name['validator']._loaded_options = None
  _globals['_VOTEINFO'].fields_by_name['validator']._serialized_options = b'\310\336\037\000'
  _globals['_EXTENDEDVOTEINFO'].fields_by_name['validator']._loaded_options = None
  _globals['_EXTENDEDVOTEINFO'].fields_by_name['validator']._serialized_options = b'\310\336\037\000'
  _globals['_MISBEHAVIOR'].fields_by_name['validator']._loaded_options = None
  _globals['_MISBEHAVIOR'].fields_by_name['validator']._serialized_options = b'\310\336\037\000'
  _globals['_MISBEHAVIOR'].fields_by_name['time']._loaded_options = None
  _globals['_MISBEHAVIOR'].fields_by_name['time']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _globals['_CHECKTXTYPE']._serialized_start=9806
  _globals['_CHECKTXTYPE']._serialized_end=9904
  _globals['_OFFERSNAPSHOTRESULT']._serialized_start=9907
  _globals['_OFFERSNAPSHOTRESULT']._serialized_end=10152
  _globals['_APPLYSNAPSHOTCHUNKRESULT']._serialized_start=10155
  _globals['_APPLYSNAPSHOTCHUNKRESULT']._serialized_end=10443
  _globals['_PROCESSPROPOSALSTATUS']._serialized_start=10446
  _globals['_PROCESSPROPOSALSTATUS']._serialized_end=10584
  _globals['_VERIFYVOTEEXTENSIONSTATUS']._serialized_start=10587
  _globals['_VERIFYVOTEEXTENSIONSTATUS']._serialized_end=10744
  _globals['_MISBEHAVIORTYPE']._serialized_start=10747
  _globals['_MISBEHAVIORTYPE']._serialized_end=10879
  _globals['_REQUEST']._serialized_start=205
  _globals['_REQUEST']._serialized_end=1436
  _globals['_ECHOREQUEST']._serialized_start=1438
  _globals['_ECHOREQUEST']._serialized_end=1477
  _globals['_FLUSHREQUEST']._serialized_start=1479
  _globals['_FLUSHREQUEST']._serialized_end=1493
  _globals['_INFOREQUEST']._serialized_start=1496
  _globals['_INFOREQUEST']._serialized_end=1640
  _globals['_INITCHAINREQUEST']._serialized_start=1643
  _globals['_INITCHAINREQUEST']._serialized_end=1977
  _globals['_QUERYREQUEST']._serialized_start=1979
  _globals['_QUERYREQUEST']._serialized_end=2079
  _globals['_CHECKTXREQUEST']._serialized_start=2081
  _globals['_CHECKTXREQUEST']._serialized_end=2170
  _globals['_COMMITREQUEST']._serialized_start=2172
  _globals['_COMMITREQUEST']._serialized_end=2187
  _globals['_LISTSNAPSHOTSREQUEST']._serialized_start=2189
  _globals['_LISTSNAPSHOTSREQUEST']._serialized_end=2211
  _globals['_OFFERSNAPSHOTREQUEST']._serialized_start=2213
  _globals['_OFFERSNAPSHOTREQUEST']._serialized_end=2318
  _globals['_LOADSNAPSHOTCHUNKREQUEST']._serialized_start=2320
  _globals['_LOADSNAPSHOTCHUNKREQUEST']._serialized_end=2416
  _globals['_APPLYSNAPSHOTCHUNKREQUEST']._serialized_start=2418
  _globals['_APPLYSNAPSHOTCHUNKREQUEST']._serialized_end=2513
  _globals['_PREPAREPROPOSALREQUEST']._serialized_start=2516
  _globals['_PREPAREPROPOSALREQUEST']._serialized_end=2926
  _globals['_PROCESSPROPOSALREQUEST']._serialized_start=2929
  _globals['_PROCESSPROPOSALREQUEST']._serialized_end=3323
  _globals['_EXTENDVOTEREQUEST']._serialized_start=3326
  _globals['_EXTENDVOTEREQUEST']._serialized_end=3715
  _globals['_VERIFYVOTEEXTENSIONREQUEST']._serialized_start=3718
  _globals['_VERIFYVOTEEXTENSIONREQUEST']._serialized_end=3874
  _globals['_FINALIZEBLOCKREQUEST']._serialized_start=3877
  _globals['_FINALIZEBLOCKREQUEST']._serialized_end=4311
  _globals['_RESPONSE']._serialized_start=4314
  _globals['_RESPONSE']._serialized_end=5631
  _globals['_EXCEPTIONRESPONSE']._serialized_start=5633
  _globals['_EXCEPTIONRESPONSE']._serialized_end=5674
  _globals['_ECHORESPONSE']._serialized_start=5676
  _globals['_ECHORESPONSE']._serialized_end=5716
  _globals['_FLUSHRESPONSE']._serialized_start=5718
  _globals['_FLUSHRESPONSE']._serialized_end=5733
  _globals['_INFORESPONSE']._serialized_start=5736
  _globals['_INFORESPONSE']._serialized_end=6115
  _globals['_INFORESPONSE_LANEPRIORITIESENTRY']._serialized_start=6050
  _globals['_INFORESPONSE_LANEPRIORITIESENTRY']._serialized_end=6115
  _globals['_INITCHAINRESPONSE']._serialized_start=6118
  _globals['_INITCHAINRESPONSE']._serialized_end=6316
  _globals['_QUERYRESPONSE']._serialized_start=6319
  _globals['_QUERYRESPONSE']._serialized_end=6567
  _globals['_CHECKTXRESPONSE']._serialized_start=6570
  _globals['_CHECKTXRESPONSE']._serialized_end=6894
  _globals['_COMMITRESPONSE']._serialized_start=6896
  _globals['_COMMITRESPONSE']._serialized_end=6961
  _globals['_LISTSNAPSHOTSRESPONSE']._serialized_start=6963
  _globals['_LISTSNAPSHOTSRESPONSE']._serialized_end=7044
  _globals['_OFFERSNAPSHOTRESPONSE']._serialized_start=7046
  _globals['_OFFERSNAPSHOTRESPONSE']._serialized_end=7132
  _globals['_LOADSNAPSHOTCHUNKRESPONSE']._serialized_start=7134
  _globals['_LOADSNAPSHOTCHUNKRESPONSE']._serialized_end=7183
  _globals['_APPLYSNAPSHOTCHUNKRESPONSE']._serialized_start=7186
  _globals['_APPLYSNAPSHOTCHUNKRESPONSE']._serialized_end=7360
  _globals['_PREPAREPROPOSALRESPONSE']._serialized_start=7362
  _globals['_PREPAREPROPOSALRESPONSE']._serialized_end=7405
  _globals['_PROCESSPROPOSALRESPONSE']._serialized_start=7407
  _globals['_PROCESSPROPOSALRESPONSE']._serialized_end=7497
  _globals['_EXTENDVOTERESPONSE']._serialized_start=7499
  _globals['_EXTENDVOTERESPONSE']._serialized_end=7558
  _globals['_VERIFYVOTEEXTENSIONRESPONSE']._serialized_start=7560
  _globals['_VERIFYVOTEEXTENSIONRESPONSE']._serialized_end=7658
  _globals['_FINALIZEBLOCKRESPONSE']._serialized_start=7661
  _globals['_FINALIZEBLOCKRESPONSE']._serialized_end=8027
  _globals['_COMMITINFO']._serialized_start=8029
  _globals['_COMMITINFO']._serialized_end=8119
  _globals['_EXTENDEDCOMMITINFO']._serialized_start=8121
  _globals['_EXTENDEDCOMMITINFO']._serialized_end=8227
  _globals['_EVENT']._serialized_start=8229
  _globals['_EVENT']._serialized_end=8352
  _globals['_EVENTATTRIBUTE']._serialized_start=8354
  _globals['_EVENTATTRIBUTE']._serialized_end=8432
  _globals['_EXECTXRESULT']._serialized_start=8435
  _globals['_EXECTXRESULT']._serialized_end=8692
  _globals['_TXRESULT']._serialized_start=8695
  _globals['_TXRESULT']._serialized_end=8829
  _globals['_VALIDATOR']._serialized_start=8831
  _globals['_VALIDATOR']._serialized_end=8890
  _globals['_VALIDATORUPDATE']._serialized_start=8892
  _globals['_VALIDATORUPDATE']._serialized_end=9007
  _globals['_VOTEINFO']._serialized_start=9010
  _globals['_VOTEINFO']._serialized_end=9159
  _globals['_EXTENDEDVOTEINFO']._serialized_start=9162
  _globals['_EXTENDEDVOTEINFO']._serialized_end=9407
  _globals['_MISBEHAVIOR']._serialized_start=9410
  _globals['_MISBEHAVIOR']._serialized_end=9671
  _globals['_SNAPSHOT']._serialized_start=9674
  _globals['_SNAPSHOT']._serialized_end=9804
# @@protoc_insertion_point(module_scope)



from typing import Any, Callable, Dict, Optional

from grpc.aio import Channel

from pyinjective.client.model.pagination import PaginationOption
from pyinjective.core.network import CookieAssistant
from pyinjective.proto.cosmos.distribution.v1beta1 import (
    query_pb2 as distribution_query_pb,
    query_pb2_grpc as distribution_query_grpc,
)
from pyinjective.utils.grpc_api_request_assistant import GrpcApiRequestAssistant


class ChainGrpcDistributionApi:
    def __init__(self, channel: Channel, cookie_assistant: CookieAssistant):
        self._stub = distribution_query_grpc.QueryStub(channel)
        self._assistant = GrpcApiRequestAssistant(cookie_assistant=cookie_assistant)

    async def fetch_module_params(self) -> Dict[str, Any]:
        request = distribution_query_pb.QueryParamsRequest()
        response = await self._execute_call(call=self._stub.Params, request=request)

        return response

    async def fetch_validator_distribution_info(self, validator_address: str) -> Dict[str, Any]:
        request = distribution_query_pb.QueryValidatorDistributionInfoRequest(validator_address=validator_address)
        response = await self._execute_call(call=self._stub.ValidatorDistributionInfo, request=request)

        return response

    async def fetch_validator_outstanding_rewards(self, validator_address: str) -> Dict[str, Any]:
        request = distribution_query_pb.QueryValidatorOutstandingRewardsRequest(validator_address=validator_address)
        response = await self._execute_call(call=self._stub.ValidatorOutstandingRewards, request=request)

        return response

    async def fetch_validator_commission(self, validator_address: str) -> Dict[str, Any]:
        request = distribution_query_pb.QueryValidatorCommissionRequest(validator_address=validator_address)
        response = await self._execute_call(call=self._stub.ValidatorCommission, request=request)

        return response

    async def fetch_validator_slashes(
        self,
        validator_address: str,
        starting_height: Optional[int] = None,
        ending_height: Optional[int] = None,
        pagination: Optional[PaginationOption] = None,
    ) -> Dict[str, Any]:
        pagination_request = None
        if pagination is not None:
            pagination_request = pagination.create_pagination_request()
        request = distribution_query_pb.QueryValidatorSlashesRequest(
            validator_address=validator_address,
            starting_height=starting_height,
            ending_height=ending_height,
            pagination=pagination_request,
        )
        response = await self._execute_call(call=self._stub.ValidatorSlashes, request=request)

        return response

    async def fetch_delegation_rewards(
        self,
        delegator_address: str,
        validator_address: str,
    ) -> Dict[str, Any]:
        request = distribution_query_pb.QueryDelegationRewardsRequest(
            delegator_address=delegator_address,
            validator_address=validator_address,
        )
        response = await self._execute_call(call=self._stub.DelegationRewards, request=request)

        return response

    async def fetch_delegation_total_rewards(
        self,
        delegator_address: str,
    ) -> Dict[str, Any]:
        request = distribution_query_pb.QueryDelegationTotalRewardsRequest(
            delegator_address=delegator_address,
        )
        response = await self._execute_call(call=self._stub.DelegationTotalRewards, request=request)

        return response

    async def fetch_delegator_validators(self, delegator_address: str) -> Dict[str, Any]:
        request = distribution_query_pb.QueryDelegatorValidatorsRequest(
            delegator_address=delegator_address,
        )
        response = await self._execute_call(call=self._stub.DelegatorValidators, request=request)

        return response

    async def fetch_delegator_withdraw_address(self, delegator_address: str) -> Dict[str, Any]:
        request = distribution_query_pb.QueryDelegatorWithdrawAddressRequest(
            delegator_address=delegator_address,
        )
        response = await self._execute_call(call=self._stub.DelegatorWithdrawAddress, request=request)

        return response

    async def fetch_community_pool(self) -> Dict[str, Any]:
        request = distribution_query_pb.QueryCommunityPoolRequest()
        response = await self._execute_call(call=self._stub.CommunityPool, request=request)

        return response

    async def _execute_call(self, call: Callable, request) -> Dict[str, Any]:
        return await self._assistant.execute_call(call=call, request=request)
